********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off

	global projectfolder "Z:\Projects\BEIS public & private R&D investment\"
	global data "$projectfolder\Data\" 									//Data downloaded
	global raw 	"$projectfolder\Econometrics\04. Analysis - Stata\raw\"	//Raw datasets 
	global do 	"$projectfolder\Econometrics\04. Analysis - Stata\do\"	//Do files
	global temp	"$projectfolder\Econometrics\04. Analysis - Stata\raw\"	//Temporary dta/excel files
	global dta 	"$projectfolder\Econometrics\04. Analysis - Stata\dta\"	//Final dta/excel files
	global charts "$projectfolder\\Econometrics\06. Tables and graphs for reports\Stata charts\"
	global tables "$projectfolder\\Econometrics\06. Tables and graphs for reports\Regression tables\"

********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	
* Merging deflator
	merge 1:1 year country using "C:\Users\Anubhav Mohanty\Documents\Projects\BEIS public & private R&D investment\Econometrics\20181217\04. Analysis - Stata\dta\190121_OECD deflator.dta"
	gen ln_pvt_gerd_constant_GBP_mn = ln(exp(ln_pvt_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	gen ln_pub_gerd_constant_GBP_mn = ln(exp(ln_pub_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	drop if _merge ==2
	xtset country_code year
	
	gen uk_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_GBP_mn = 0 if uk_ln_pub_gerd_constant_GBP_mn == .
	
	gen oth_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_GBP_mn = 0 if oth_ln_pub_gerd_constant_GBP_mn == .

		
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
* Correction for interest rates (missing values wrongly coded as zero)
	drop _merge
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\190121_Q4_3_OECD panel - GBP - June lag structure.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020
	
********************************************************************************
		
* Dynamic panel - 1								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
			
* Dynamic panel - 2								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons 	
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
		
* Dynamic panel - 3								
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
********************************************************************************
	
* Dynamic panel - 1								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l.uk_ln_pub_gerd_constant_GBP_mn l.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(l.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons
		nlcom( _b[l.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
			
* Dynamic panel - 2								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l.uk_ln_pub_gerd_constant_GBP_mn l.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(l.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons 	
		nlcom( _b[l.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
		
* Dynamic panel - 3								
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l.uk_ln_pub_gerd_constant_GBP_mn l.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(l.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[l.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
********************************************************************************
	
* Dynamic panel - 1								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l2.uk_ln_pub_gerd_constant_GBP_mn l2.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(l2.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l2.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons
		nlcom( _b[l2.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
			
* Dynamic panel - 2								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l2.uk_ln_pub_gerd_constant_GBP_mn l2.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(l2.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l2.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons 	
		nlcom( _b[l2.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
		
* Dynamic panel - 3								
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			 l2.uk_ln_pub_gerd_constant_GBP_mn  l2.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm( l2.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm( l2.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[ l2.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
********************************************************************************
	
* Dynamic panel - 1								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l3.uk_ln_pub_gerd_constant_GBP_mn l3.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(l3.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l3.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons
		nlcom( _b[l3.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
			
* Dynamic panel - 2								
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l3.uk_ln_pub_gerd_constant_GBP_mn l3.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(l3.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l3.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons 	
		nlcom( _b[l3.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
		
* Dynamic panel - 3								
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			l3.uk_ln_pub_gerd_constant_GBP_mn l3.oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(l3.oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l3.uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[ l3.uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel

