********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off

	*global projectfolder "Z:\Projects\BEIS public & private R&D investment\"
	global projectfolder "C:\Users\Anubhav Mohanty\Documents\Projects\BEIS public & private R&D investment\Econometrics\20181217\"
	global received "$projectfolder\01. Received\"
	global data "$projectfolder\03. Data\" 				//Existing datsets
	global raw 	"$projectfolder\04. Analysis - Stata\raw\"	//Raw datasets 
	global do 	"$projectfolder\04. Analysis - Stata\do\"	//Do files
	global temp	"$projectfolder\04. Analysis - Stata\temp\"	//Temporary dta/excel files
	global dta 	"$projectfolder\04. Analysis - Stata\dta\"	//Final dta/excel files
	global charts "$projectfolder\06. Tables and graphs for reports\Stata charts\"
	global tables "$projectfolder\06. Tables and graphs for reports\Regression tables\"
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\20190121_Q5_3_3a_OECD panel BERD and HERD ratio.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end
	


********************************************************************************
* IMporting the dataset
	use "$dta\190121_(Q5.3.1)_OECD_for_regressions(NEW).dta", replace

* Identifying new datapoints
	gen new = 0
	replace new = 1 if 	( pvt_gerd_constant_USD_mn_new != . &  pvt_gerd_constant_USD_mn_old == .) ///
						&(pub_herd_constant_USD_mn_new != . & pub_herd_constant_USD_mn_old == .) ///
						& (pub_berd_constant_USD_mn_new != . & pub_berd_constant_USD_mn_old == .)
	
* Generate ratios 
	gen pub_herd_ratio = pub_herd_constant_USD_mn_new /pub_gerd_constant_USD_mn_new 
	gen pub_berd_ratio = pub_berd_constant_USD_mn_new /pub_gerd_constant_USD_mn_new 
	gen pub_taxc_ratio = pub_txcred_constant_USD_mn/pub_gerd_constant_USD_mn_new 
********************************************************************************
	* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_USD_mn_old l.ln_pvt_gerd_constant_USD_mn_old ///
			d.ln_employment_thousands_old intrates_old ///
			ln_pub_herd_constant_USD_mn_old  ln_pub_berd_constant_USD_mn_old  , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_old , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn_old, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn_old, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands_old , laglimit(1 6)  coll  ) ///
			iv(intrates_old) ///
			robust orth nodiffsargan 
		predict val, xb
		nlcom (_b[ln_pub_herd_constant_USD_mn ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		nlcom (_b[ln_pub_berd_constant_USD_mn ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		export_dynamic_panel
		
	* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_herd_constant_USD_mn_new  ln_pub_berd_constant_USD_mn_new if val != . | (new == 1 & year >1990)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 
			nlcom (_b[ln_pub_herd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
			nlcom (_b[ln_pub_berd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
		export_dynamic_panel
		
	* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_gerd_constant_USD_mn_new if val != . | (new == 1 & year >1990)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 
		
		export_dynamic_panel
		
	* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_gerd_constant_USD_mn_new  pub_herd_ratio  if val != . | (new == 1 & year >1990)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 
			
		export_dynamic_panel
		
		* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_gerd_constant_USD_mn_new  pub_berd_ratio  if val != . | (new == 1 & year >1990)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new  , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 
			
		export_dynamic_panel
		
		* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_gerd_constant_USD_mn_new  pub_taxc_ratio  if val != . | (new == 1 & year >1990)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new  , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 
			
		export_dynamic_panel
		
		* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_gerd_constant_USD_mn_new  pub_berd_ratio pub_herd_ratio  if val != . | (new == 1 & year >1990)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 

		export_dynamic_panel
		
				* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_gerd_constant_USD_mn_new  pub_berd_ratio pub_herd_ratio pub_taxc_ratio if val != . | (new == 1 & year >1990)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 
			
		export_dynamic_panel
