********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off


	*global projectfolder "Z:\Projects\BEIS public & private R&D investment\"
	global projectfolder "C:\Users\Anubhav Mohanty\Documents\Projects\BEIS public & private R&D investment\Econometrics\20181217\"
	global received "$projectfolder\01. Received\"
	global data "$projectfolder\03. Data\" 				//Existing datsets
	global raw 	"$projectfolder\04. Analysis - Stata\raw\"	//Raw datasets 
	global do 	"$projectfolder\04. Analysis - Stata\do\"	//Do files
	global temp	"$projectfolder\04. Analysis - Stata\temp\"	//Temporary dta/excel files
	global dta 	"$projectfolder\04. Analysis - Stata\dta\"	//Final dta/excel files
	global charts "$projectfolder\06. Tables and graphs for reports\Stata charts\"
	global tables "$projectfolder\06. Tables and graphs for reports\Regression tables\"

	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Q5_3_OECD panel_BERD and HERD (TAX CRED).xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

********************************************************************************
* Use R&D dataset
	use "$dta\190107_(Q5.3.1)_OECD_for_regressions(NEW).dta", replace

* * Generate decades
	generate 	decade = "pre-2000s" if year <2000
	replace		decade = "2001-2005" if year > = 2000 & year <= 2005
	replace		decade = "2006-2010" if year > = 2006 & year <= 2010
	replace		decade = "2010-2015" if year > = 2011 & year <= 2015
	replace		decade = "2016" if year > = 2016
	
* Merging tax credits data	
	gen pvt_gerd_constant_GBP_mn_adj = pvt_gerd_constant_USD_mn_adj/ex_rate_perGBP*ex_rate_perusd
	gen pub_herd_constant_GBP_mn_new = pub_herd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen pub_berd_constant_GBP_mn_new = pub_berd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen pub_oth_constant_GBP_mn_new = pub_oth_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen pub_txcred_constant_GBP_mn = pub_txcred_constant_USD_mn/ex_rate_perGBP*ex_rate_perusd
	
	gen ln_pvt_gerd_constant_GBP_mn_adj = ln(pvt_gerd_constant_GBP_mn_adj)
	gen ln_pub_herd_constant_GBP_mn_new = ln(pub_herd_constant_GBP_mn_new)
	gen ln_pub_berd_constant_GBP_mn_new = ln(pub_berd_constant_GBP_mn_new)
	gen ln_pub_oth_constant_GBP_mn_new = ln(pub_oth_constant_GBP_mn_new)
	gen ln_pub_txcred_constant_GBP_mn = ln(pub_txcred_constant_GBP_mn)
	
	replace ln_employment_thousands_old  = ln_employment_na_thousands if ln_employment_thousands_old  == .
********************************************************************************
* Static panel - no lag
xtreg ln_pvt_gerd_constant_GBP_mn_adj ln_pub_txcred_constant_GBP_mn, robust fe
outreg2 using "$tables\\Q5_3_OECD panel_BERD and HERD (TAX CRED).xls", dec(4) append ctitle(Static Panel) 

* Static panel - with lag - fe
xtreg ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj  ln_pub_txcred_constant_GBP_mn, robust fe
outreg2 using "$tables\\Q5_3_OECD panel_BERD and HERD (TAX CRED).xls", dec(4) append ctitle(Static Panel - Fixed Eff.) 

* Static panel - with lag - re
xtreg ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj  ln_pub_txcred_constant_GBP_mn, robust re
outreg2 using "$tables\\Q5_3_OECD panel_BERD and HERD (TAX CRED).xls", dec(4) append ctitle(Static Panel - Random Eff.) 

* Static panel - with lag and growth - fe
xtreg d.ln_pvt_gerd_constant_GBP_mn_adj d.l.ln_pvt_gerd_constant_GBP_mn_adj  d.ln_pub_txcred_constant_GBP_mn, robust fe
outreg2 using "$tables\\Q5_3_OECD panel_BERD and HERD (TAX CRED).xls", dec(4) append ctitle(Static Panel - Fixed Eff.) 

* Static panel - - with lag and growth - re
xtreg d.ln_pvt_gerd_constant_GBP_mn_adj d.l.ln_pvt_gerd_constant_GBP_mn_adj  d.ln_pub_txcred_constant_GBP_mn, robust re
outreg2 using "$tables\\Q5_3_OECD panel_BERD and HERD (TAX CRED).xls", dec(4) append ctitle(Static Panel - Random Eff.) 


* Dynamic panel - 1
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 1) coll  ) ///
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 1)  coll  ) ///
			robust orth nodiffsargan 
			predict val, xb
		export_dynamic_panel

* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn ln_employment_thousands , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
			gmm(ln_employment_thousands , laglimit(1 2)  coll  ) ///
			robust orth nodiffsargan 
	export_dynamic_panel

* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_GBP_mn_new  ln_pub_berd_constant_GBP_mn_new , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_GBP_mn_new, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_GBP_mn_new , laglimit(1 3)  coll  ) ///
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
	export_dynamic_panel
	
* Dynamic panel - 2
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
		ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates  ///
		ln_pub_herd_constant_GBP_mn_new  ln_pub_berd_constant_GBP_mn_new, ///
		gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
		gmm(ln_pub_herd_constant_GBP_mn_new, laglimit(3 3)  coll  ) ///  
		gmm(ln_pub_berd_constant_GBP_mn_new , laglimit(1 3)  coll  ) ///
		gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
		gmm(d.ln_employment_thousands  , laglimit(1 2)  coll  ) ///
		iv(intrates HHI) ///
		robust orth nodiffsargan 
	export_dynamic_panel
		
* Dynamic panel - 4
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
		ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates HHI ln_ex_rate_perusd ///
		ln_pub_herd_constant_GBP_mn_new  ln_pub_berd_constant_GBP_mn_new , ///
		gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
		gmm(ln_pub_herd_constant_GBP_mn_new, laglimit(3 3)  coll  ) ///  
		gmm(ln_pub_berd_constant_GBP_mn_new, laglimit(1 3)  coll  ) ///
		gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
		gmm(d.ln_employment_thousands HHI , laglimit(1 2)  coll  ) ///
		iv(intrates ln_ex_rate_perusd) ///
		robust orth nodiffsargan 
	export_dynamic_panel

* Dynamic panel - 5
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates ///
			ln_pub_berd_constant_GBP_mn_new , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
			gmm(ln_pub_berd_constant_GBP_mn_new, laglimit(1 3)  coll  ) ///
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
	export_dynamic_panel
	
* Dynamic panel - 6
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_GBP_mn_new   , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 3) coll  ) ///
			gmm(ln_pub_herd_constant_GBP_mn_new, laglimit(2 3)  coll  ) ///  
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll  ) ///
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
			iv(intrates ln_pub_berd_constant_GBP_mn_new) ///
			robust orth nodiffsargan 
			
	export_dynamic_panel
	
* OTHER Types of public funding
* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_GBP_mn_new  ln_pub_berd_constant_GBP_mn_new ln_pub_oth_constant_GBP_mn_new , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_GBP_mn_new , laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_GBP_mn_new ln_pub_oth_constant_GBP_mn_new, laglimit(1 3)  coll  ) ///
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
	export_dynamic_panel
	
* Dynamic panel - 2
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_GBP_mn_new  ln_pub_berd_constant_GBP_mn_new ln_pub_oth_constant_GBP_mn_new , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_GBP_mn_new, laglimit(1 3)  coll  ) ///  
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
			gmm(ln_pub_berd_constant_GBP_mn_new ln_pub_oth_constant_GBP_mn_new, laglimit(1 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_GBP_mn_adj l.ln_pvt_gerd_constant_GBP_mn_adj ///
			ln_pub_txcred_constant_GBP_mn d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_adj , laglimit(1 2) coll  ) ///
			gmm(ln_pub_txcred_constant_GBP_mn, laglimit(1 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
	export_dynamic_panel
	
	
