********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off

	*global projectfolder "Z:\Projects\BEIS public & private R&D investment\"
	global projectfolder "C:\Users\Anubhav Mohanty\Documents\Projects\BEIS public & private R&D investment\Econometrics\20181217\"
	global received "$projectfolder\01. Received\"
	global data "$projectfolder\03. Data\" 				//Existing datsets
	global raw 	"$projectfolder\04. Analysis - Stata\raw\"	//Raw datasets 
	global do 	"$projectfolder\04. Analysis - Stata\do\"	//Do files
	global temp	"$projectfolder\04. Analysis - Stata\temp\"	//Temporary dta/excel files
	global dta 	"$projectfolder\04. Analysis - Stata\dta\"	//Final dta/excel files
	global charts "$projectfolder\06. Tables and graphs for reports\Stata charts\"
	global tables "$projectfolder\06. Tables and graphs for reports\Regression tables\"
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\190131_Q4_3_OECD panel - NEW - UNADJ)1.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

********************************************************************************
* Use R&D dataset
	use "$dta\190121_(Q5.5.1)_OECD_for_regressions(NEW).dta", clear
	
* Conversion to GBP	
	gen pub_gerd_constant_GBP_mn_new = pub_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen pvt_gerd_constant_GBP_mn_new = pvt_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen GDP_constant_GBP_mn  = GDP_constant_USD_mn /ex_rate_perGBP*ex_rate_perusd
	
	gen ln_pub_gerd_constant_GBP_mn_new = ln(pub_gerd_constant_GBP_mn_new)
	gen ln_pvt_gerd_constant_GBP_mn_new = ln(pvt_gerd_constant_GBP_mn_new)
	gen ln_GDP_constant_GBP_mn = ln(GDP_constant_GBP_mn)

* Generating country specific variables
	gen fr_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "France"
	replace fr_ln_pub_gerd_cons_USD_mn = 0 if fr_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_fr_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "France"
	replace oth_fr_ln_pub_gerd_cons_USD_mn = 0 if oth_fr_ln_pub_gerd_cons_USD_mn == .
	
* Generating country specific variables
	gen de_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "Germany"
	replace de_ln_pub_gerd_cons_USD_mn = 0 if de_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_de_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "Germany"
	replace oth_de_ln_pub_gerd_cons_USD_mn = 0 if oth_de_ln_pub_gerd_cons_USD_mn == .
	
	gen us_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "United States"
	replace us_ln_pub_gerd_cons_USD_mn = 0 if us_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_us_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "United States"
	replace oth_us_ln_pub_gerd_cons_USD_mn = 0 if oth_us_ln_pub_gerd_cons_USD_mn == .
	
	gen can_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "Canada"
	replace can_ln_pub_gerd_cons_USD_mn = 0 if can_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_can_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "Canada"
	replace oth_can_ln_pub_gerd_cons_USD_mn = 0 if oth_can_ln_pub_gerd_cons_USD_mn == .
	
	gen fin__ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "Finland"
	replace fin__ln_pub_gerd_cons_USD_mn = 0 if fin__ln_pub_gerd_cons_USD_mn == .
	
	gen oth_fin__ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "Finland"
	replace oth_fin__ln_pub_gerd_cons_USD_mn = 0 if oth_fin__ln_pub_gerd_cons_USD_mn == .
	
	gen ita_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "Italy"
	replace ita_ln_pub_gerd_cons_USD_mn = 0 if ita_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_ita_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "Italy"
	replace oth_ita_ln_pub_gerd_cons_USD_mn = 0 if oth_ita_ln_pub_gerd_cons_USD_mn == .
	
	
	gen jp_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "Japan"
	replace jp_ln_pub_gerd_cons_USD_mn = 0 if jp_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_jp_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "Japan"
	replace oth_jp_ln_pub_gerd_cons_USD_mn = 0 if oth_jp_ln_pub_gerd_cons_USD_mn == .
	
	gen nor_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "Norway"
	replace nor_ln_pub_gerd_cons_USD_mn = 0 if nor_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_nor_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "Norway"
	replace oth_nor_ln_pub_gerd_cons_USD_mn = 0 if oth_nor_ln_pub_gerd_cons_USD_mn == .
	
	gen esp_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "Spain"
	replace esp_ln_pub_gerd_cons_USD_mn = 0 if  esp_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_esp_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "Spain"
	replace oth_esp_ln_pub_gerd_cons_USD_mn = 0 if oth_esp_ln_pub_gerd_cons_USD_mn == .
	
	gen uk_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "United Kingdom"
	replace uk_ln_pub_gerd_cons_USD_mn = 0 if uk_ln_pub_gerd_cons_USD_mn == .
	
	gen oth_uk_ln_pub_gerd_cons_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "United Kingdom"
	replace oth_uk_ln_pub_gerd_cons_USD_mn = 0 if oth_uk_ln_pub_gerd_cons_USD_mn == .
	
* Generate decades
	
* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020
	
* Generate new and old identifiers
	gen new = 0 
	replace new =1 if pvt_gerd_constant_USD_mn_new != . & pvt_gerd_constant_USD_mn_old == .
		
********************************************************************************
		
* Dynamic panel - 4								
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
			ln_pub_gerd_constant_USD_mn_new  ///
			d.ln_employment_na_thousands intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_new  , laglimit(1 1)  coll orth ) ///
			gmm(ln_pub_gerd_constant_USD_mn_new  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates i.decade ) ///
			robust orth nodiffsargan
		nlcom (_b[ln_pub_gerd_constant_USD_mn_new]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
		export_dynamic_panel
		
foreach i in esp_ uk_ fr_ de_ us_ ita_ jp_ nor_ fin__ can_ { 
* Dynamic panel - 4								
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
			 oth_`i'ln_pub_gerd_cons_USD_mn ///
			d.ln_employment_na_thousands intrates ///
			`i'ln_pub_gerd_cons_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_new  , laglimit(1 1)  coll orth ) ///
			gmm(oth_`i'ln_pub_gerd_cons_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(`i'ln_pub_gerd_cons_USD_mn , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  ) ///
			robust orth nodiffsargan
		*nlcom (_b[`i'ln_pub_gerd_cons_USD_mn]/(1-l.ln_pvt_gerd_constant_USD_mn_new))
		export_dynamic_panel
			
	
} 
* Dynamic panel - 4								
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
			uk_ln_pub_gerd_cons_USD_mn oth_uk_ln_pub_gerd_cons_USD_mn ///
			d.ln_employment_na_thousands intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_new  , laglimit(1 1)  coll orth ) ///
			gmm(oth_uk_ln_pub_gerd_cons_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_cons_USD_mn , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  ) ///
			robust orth nodiffsargan
		export_dynamic_panel
