********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off

	global projectfolder "Z:\Projects\BEIS public & private R&D investment\"
	global data "$projectfolder\Data\" 									//Data downloaded
	global raw 	"$projectfolder\Econometrics\04. Analysis - Stata\raw\"	//Raw datasets 
	global do 	"$projectfolder\Econometrics\04. Analysis - Stata\do\"	//Do files
	global temp	"$projectfolder\Econometrics\04. Analysis - Stata\raw\"	//Temporary dta/excel files
	global dta 	"$projectfolder\Econometrics\04. Analysis - Stata\dta\"	//Final dta/excel files
	global charts "$projectfolder\\Econometrics\06. Tables and graphs for reports\Stata charts\"
	global tables "$projectfolder\\Econometrics\06. Tables and graphs for reports\Regression tables\"

********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	
* Correction for interest rates (missing values wrongly coded as zero)
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	xtset country_code year
	replace country = "South Korea" if country == "Korea"
	drop _merge 
	
* Merging deflator
	merge 1:1 year country using "C:\Users\Anubhav Mohanty\Documents\Projects\BEIS public & private R&D investment\Econometrics\20181217\04. Analysis - Stata\dta\190121_OECD deflator.dta"
	gen ln_pvt_gerd_constant_USD_mn_new = ln(exp(ln_pvt_gerd_constant_USD_mn)*CPI/deflator)
	gen ln_pub_gerd_constant_USD_mn_new = ln(exp(ln_pub_gerd_constant_USD_mn)*CPI/deflator)
	drop if _merge ==2
	xtset country_code year
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\190121_Q4_3_OECD panel - Deflator sensitivity.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end
	
********************************************************************************
* Dynamic panel - 1								
		xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ln_pub_gerd_constant_USD_mn_new intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_new ln_pub_gerd_constant_USD_mn_new  , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
			
* Dynamic panel - 2								
		xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ln_pub_gerd_constant_USD_mn_new ///
			ln_GDP_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_new ln_pub_gerd_constant_USD_mn_new  , laglimit(1 2)  coll orth ) ///
			gmm(ln_GDP_constant_USD_mn, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		export_dynamic_panel
			
* Dynamic panel - 3								
		xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ln_pub_gerd_constant_USD_mn_new ///
			ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_new ln_pub_gerd_constant_USD_mn_new  , laglimit(1 2)  coll orth ) ///
			gmm(ln_employment_thousands, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		export_dynamic_panel
		
* Dynamic panel - 1								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
			
* Dynamic panel - 2								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			ln_GDP_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(ln_GDP_constant_USD_mn, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		export_dynamic_panel
			
* Dynamic panel - 3								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(ln_employment_thousands, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		export_dynamic_panel
			

