********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off

	*global projectfolder "Z:\Projects\BEIS public & private R&D investment\"
	global projectfolder "C:\Users\Anubhav Mohanty\Documents\Projects\BEIS public & private R&D investment\Econometrics\20181217\"
	global received "$projectfolder\01. Received\"
	global data "$projectfolder\03. Data\" 				//Existing datsets
	global raw 	"$projectfolder\04. Analysis - Stata\raw\"	//Raw datasets 
	global do 	"$projectfolder\04. Analysis - Stata\do\"	//Do files
	global temp	"$projectfolder\04. Analysis - Stata\temp\"	//Temporary dta/excel files
	global dta 	"$projectfolder\04. Analysis - Stata\dta\"	//Final dta/excel files
	global charts "$projectfolder\06. Tables and graphs for reports\Stata charts\"
	global tables "$projectfolder\06. Tables and graphs for reports\Regression tables\"
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Q4_3_OECD panel - TOT (NEW - UNADJ) - Year dummies.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

********************************************************************************
* Use R&D dataset
	use "$dta\181220_(Q5.5.1)_OECD_for_regressions(NEW).dta", clear
	
* Conversion to GBP	
	gen pub_gerd_constant_GBP_mn_new = pub_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen pvt_gerd_constant_GBP_mn_new = pvt_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	
	gen ln_pub_gerd_constant_GBP_mn_new = ln(pub_gerd_constant_GBP_mn_new)
	gen ln_pvt_gerd_constant_GBP_mn_new = ln(pvt_gerd_constant_GBP_mn_new)
	
* Generating year dummies
	gen dum_90s = 0
	gen dum_00s = 0
	gen dum_10s = 0 
	
	replace dum_90s = 1 if year>=1990 & year < 2000
	replace dum_00s = 1 if year>=2000 & year < 2010
	replace dum_10s = 1 if year>=2010 
	
	gen post_2008 = 0
	replace post_2008 = 1 if year >= 2008
	
	
********************************************************************************
* Dynamic panel - 1								
		xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new ///
			ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates post_2008, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new , laglimit(1 2)  coll orth ) ///
			gmm(ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates post_2008) ///
			robust orth nodiffsargan 
		nlcom(_b[ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel
		
* Dynamic panel - 2								
		xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new ///
			ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates post_2008, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new  , laglimit(2 2)  coll orth ) ///
			gmm(ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates post_2008) ///
			robust orth nodiffsargan
		nlcom(_b[ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel
			
********************************************************************************
* Dynamic panel - 1								
		xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new ///
			ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates post_2008 dum_90s dum_00s dum_10s, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new , laglimit(1 2)  coll orth ) ///
			gmm(ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates post_2008 dum_90s dum_00s dum_10s) ///
			robust orth nodiffsargan 
		nlcom(_b[ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel
		
* Dynamic panel - 2								
		xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new ///
			ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates post_2008 dum_90s dum_00s dum_10s, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new  , laglimit(2 2)  coll orth ) ///
			gmm(ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates post_2008 dum_90s dum_00s dum_10s) ///
			robust orth nodiffsargan
		nlcom(_b[ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel
			
	
