********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics (Edited by Joshua Sarracino) *
********************************************************************************

* Preliminaries (defining filepaths)
	sysdir set PLUS "L:\StataLib\ado\plus"

clear
set more off

capture log close

global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
global tables "$projectfolder\\Data and Tables\Tables 070219\"
global dta "$projectfolder\\Data and Tables\Data 070219\"
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\20190121_Q5_3_3a_OECD panel (BERD and HERD) - NEW.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end
	


********************************************************************************
* IMporting the dataset
	use "$dta\190121_(Q5.3.1)_OECD_for_regressions(NEW).dta", replace

* Identifying new datapoints
	gen new = 0
	replace new = 1 if 	( pvt_gerd_constant_USD_mn_new != . &  pvt_gerd_constant_USD_mn_old == .) ///
						&(pub_herd_constant_USD_mn_new != . & pub_herd_constant_USD_mn_old == .) ///
						& (pub_berd_constant_USD_mn_new != . & pub_berd_constant_USD_mn_old == .)
	
********************************************************************************
* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_USD_mn_old l.ln_pvt_gerd_constant_USD_mn_old ///
			d.ln_employment_thousands_old intrates_old ///
			ln_pub_herd_constant_USD_mn_old  ln_pub_berd_constant_USD_mn_old  , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_old , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn_old, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn_old, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands_old , laglimit(1 6)  coll  ) ///
			iv(intrates_old) ///
			robust orth nodiffsargan 
		predict val, xb
		nlcom (_b[ln_pub_herd_constant_USD_mn ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		nlcom (_b[ln_pub_berd_constant_USD_mn ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		export_dynamic_panel
	
	* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands   intrates  ///
				ln_pub_herd_constant_USD_mn_new  ln_pub_berd_constant_USD_mn_new  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(1 1)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 4)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 2)  coll  ) ///
				iv( intrates) ///
				robust orth nodiffsargan 
			nlcom (_b[ln_pub_herd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
			nlcom (_b[ln_pub_berd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
		export_dynamic_panel
			
	* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands   intrates  ///
				ln_pub_herd_constant_USD_mn_new  ln_pub_berd_constant_USD_mn_new if val != . | (new == 1 & year >1980)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(1 1)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 4)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 4)  coll  ) ///
				iv( i.decade) ///
				robust orth nodiffsargan 
			nlcom (_b[ln_pub_herd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
			nlcom (_b[ln_pub_berd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
		export_dynamic_panel

	* Dynamic panel - 2	
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
				d.ln_employment_na_thousands  intrates  ///
				ln_pub_herd_constant_USD_mn_new  ln_pub_berd_constant_USD_mn_new if val != . | (new == 1 & year >1980)  , ///
				gmm(l.ln_pvt_gerd_constant_USD_mn_new , laglimit(1 2) coll  ) ///
				gmm(ln_pub_herd_constant_USD_mn_new, laglimit(3 3)  coll  ) ///  
				gmm(ln_pub_berd_constant_USD_mn_new, laglimit(2 3)  coll  ) ///
				gmm(d.ln_employment_na_thousands  , laglimit(1 6)  coll  ) ///
				iv( intrates i.decade) ///
				robust orth nodiffsargan 
			nlcom (_b[ln_pub_herd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
			nlcom (_b[ln_pub_berd_constant_USD_mn_new ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
		export_dynamic_panel

