********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
*			Author:  Oxford Economics (Edited by Armand Viaje-Balog)		   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 301018\"
	global dta "$projectfolder\\Data and Tables\Data 301018\"
	global temp	"$projectfolder\\Data and Tables\Data 301018\temp\"
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Q5_3_3a_OECD panel (BERD and HERD).xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5_3_1and2_BERD and HERD panel_for_reg.dta", replace
********************************************************************************
* Figure 31 - Model 1
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		nlcom (_b[ln_pub_herd_constant_USD_mn ]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		export_dynamic_panel

* Figure 31 - Model 2
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates  ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands  , laglimit(1 6)  coll  ) ///
			iv(intrates HHI) ///
			robust orth nodiffsargan 
		export_dynamic_panel
	
* Figure 31 - Model 3
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands HHI , laglimit(1 6)  coll  ) ///
			iv(intrates  ) ///
			robust orth nodiffsargan 
		export_dynamic_panel

* Figure 31 - Model 4
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands HHI  , laglimit(1 6)  coll  ) ///
			iv(intrates exports_GDPshare) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Figure 31 - Model 5
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Figure 31 - Model 6
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn   , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 3) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(2 3)  coll  ) ///  
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates ln_pub_berd_constant_USD_mn) ///
			robust orth nodiffsargan 
		export_dynamic_panel

