********************************************************************************
****************** 	BEIS Alternative Specificaton analysis  ********************
******************     		Date: 25/02/2019                ********************
****************** 			Joshua Sarracino                ********************
********************************************************************************

* Preliminaries (defining filepaths)
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off

	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 070219\"
	global dta "$projectfolder\\Data and Tables\Data 070219\"
	
********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	
* Merging deflator
	merge 1:1 year country using "$dta\190121_OECD deflator.dta"
	gen ln_pvt_gerd_constant_GBP_mn = ln(exp(ln_pvt_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	gen ln_pub_gerd_constant_GBP_mn = ln(exp(ln_pub_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	drop if _merge ==2
	xtset country_code year
	
	gen uk_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_GBP_mn = 0 if uk_ln_pub_gerd_constant_GBP_mn == .
	
	gen oth_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_GBP_mn = 0 if oth_ln_pub_gerd_constant_GBP_mn == .

		
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
* Correction for interest rates (missing values wrongly coded as zero)
	drop _merge
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year
	
* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020
	
* Code to export results
	capture program drop export_dynamic_panel_fig17
	program define	export_dynamic_panel_fig17
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Fig17 alternative specs.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end
	
	
* R&D Intensity		
* generate variables for R&D intensities. That is, R&D soending as a proportion of GDP. (Actually, it's nat. log of R&D intensities.)  
	gen pvt_randd_intensity=ln_pvt_gerd_constant_USD_mn-ln(GDP_constant_USD_mn)
	gen pub_randd_intensity=ln_pub_gerd_constant_USD_mn-ln(GDP_constant_USD_mn)
	
* Generate log of intrest rates
	gen ln_intrate=ln(intrates)	

* summary statsitics (check for high Kurtosis)
	su pvt_randd_intensity pub_randd_intensity, detail
	su ln_intrate d.ln_employment_thousands, detail

***************** FE vs OLS vs GMM *********************************************
**** Range Checking

* Figure 17: Model 3 - BB
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17

* Figure 17: Model 3 - AB
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nolevel nocons
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17

* Figure 17: Model 3 - FE
	xtreg ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ln_intrate d.ln_employment_thousands, fe robust 
	outreg2 using "$tables\\Fig17 alternative specs.xls", dec(4) append ///
			ctitle(FE - FIG 17 Model 3)
	
	*xtreg ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ln_intrate d.ln_employment_thousands i.decade, fe robust
		
* Figure 17: Model 3 - OLS
	reg ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ln_intrate d.ln_employment_thousands, robust
	outreg2 using "$tables\\Fig17 alternative specs.xls", dec(4) append ///
			ctitle(OLS - FIG 17 Model 3)	
			
	*reg ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ln_intrate d.ln_employment_thousands i.decade, robust
	
	
**** R&D Intensity Regressions
* AB (with predtermined 'x' and emp. growth)
	
	xtabond2 pvt_randd_intensity l.pvt_randd_intensity ///
		pub_randd_intensity ln_intrate d.ln_employment_thousands,  ///
		gmm(l.pvt_randd_intensity , laglimit(1 3)  coll orth ) ///
		gmm(pub_randd_intensity, laglimit (1 3) coll orth) ///
		gmm(d.ln_employment_thousands, laglimit(1 3) coll orth) ///
		iv(ln_intrate) robust orth  nolevel
		export_dynamic_panel_fig17
		
	/*	
	xi: xtabond2 pvt_randd_intensity l.pvt_randd_intensity ///
		pub_randd_intensity ///
		ln_intrate d.ln_employment_thousands,  ///
		gmm(l.pvt_randd_intensity , laglimit(2 2)  coll orth ) ///
		gmm(pub_randd_intensity, laglimit(1 3)  coll orth) ///
		gmm(d.ln_employment_thousands, laglimit(1 1) coll orth) ///
		iv(ln_intrate i.decade) ///
		robust orth  nolevel
		export_dynamic_panel_fig17		
		*/
  
* BB (with predtermined 'x' and emp. growth)
	
	xtabond2 pvt_randd_intensity l.pvt_randd_intensity ///
		pub_randd_intensity ln_intrate d.ln_employment_thousands,  ///
		gmm(l.pvt_randd_intensity , laglimit(1 3)  coll orth ) ///
		gmm(pub_randd_intensity, laglimit (1 3) coll orth) ///
		gmm(d.ln_employment_thousands, laglimit(1 3) coll orth) ///
		iv(ln_intrate) robust orth  
		export_dynamic_panel_fig17
		
	/*	
	xi: xtabond2 pvt_randd_intensity l.pvt_randd_intensity ///
		pub_randd_intensity ///
		ln_intrate d.ln_employment_thousands,  ///
		gmm(l.pvt_randd_intensity , laglimit(2 2)  coll orth ) ///
		gmm(pub_randd_intensity, laglimit(1 3)  coll orth) ///
		gmm(d.ln_employment_thousands, laglimit(1 1) coll orth) ///
		iv(ln_intrate i.decade) ///
		robust orth 
		export_dynamic_panel_fig17		
  */
  
* FE  
	xtreg pvt_randd_intensity l.pvt_randd_intensity pub_randd_intensity ln_intrate d.ln_employment_thousands, fe robust
	outreg2 using "$tables\\Fig17 alternative specs.xls", dec(4) append ///
			ctitle(FE - R&D Intensity)
	
	xtreg pvt_randd_intensity l.pvt_randd_intensity pub_randd_intensity ln_intrate d.ln_employment_thousands i. year, fe robust
	outreg2 using "$tables\\Fig17 alternative specs.xls", dec(4) append ///
			ctitle(FE - R&D Intensity)

* OLS
	reg pvt_randd_intensity l.pvt_randd_intensity pub_randd_intensity ln_intrate d.ln_employment_thousands, robust
	outreg2 using "$tables\\Fig17 alternative specs.xls", dec(4) append ///
			ctitle(OLS - R&D Intensity)
	
	reg pvt_randd_intensity l.pvt_randd_intensity pub_randd_intensity ln_intrate d.ln_employment_thousands i.year, robust
	outreg2 using "$tables\\Fig17 alternative specs.xls", dec(4) append ///
			ctitle(OLS - R&D Intensity)
	
	
	
*********************** With Constant ******************************************
* Figure 17: Model 1
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17
		
* Figure 17: Model 2							
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan  	
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17
			
* Figure 17: Model 3
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17
		
* Figure 17: Model 4
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		export_dynamic_panel_fig17


		
		
****************** With Log int rate *******************************************

* Figure 17: Model 1
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands ln_intrate, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(ln_intrate) ///
			robust orth nodiffsargan 
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17
		
* Figure 17: Model 2							
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands ln_intrate, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(ln_intrate) ///
			robust orth nodiffsargan  	
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17
			
* Figure 17: Model 3
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands ln_intrate, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(ln_intrate i.decade) ///
			robust orth nodiffsargan
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17
		
* Figure 17: Model 4
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands ln_intrate, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(ln_intrate) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		export_dynamic_panel_fig17	
	