********************************************************************************
****************** BEIS Exchange Rate Sensitivity analysis  ********************
******************     		Date: 25/02/2019                ********************
****************** 			Joshua Sarracino                ********************
********************************************************************************


* Preliminaries 
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off
	
	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 070219\"
	global data "$projectfolder\\Data and Tables\Extra data\"
	global dta "$projectfolder\\Data and Tables\Data 070219\"
	
* Export the Fig17 replication Results
capture program drop export_dynamic_panel_fig17
	program define	export_dynamic_panel_fig17
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Fig17 ex rate sens.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end


		
***** Exchange Rate additions  *****
/*
import excel "$data\Implicit exchange rates from OECD GDP 20181218 .xlsx", sheet("ex_rate") firstrow
save "$data\ex_rates_for_leverage.dta" , replace
use "$data\ex_rates_for_leverage.dta" 
replace country="South Korea" if country=="Korea"
save "$data\ex_rates_for_leverage.dta", replace
clear

*calculating fixed USD at 2010 ex_rate
use "$data\ex_rates_for_leverage.dta"
drop if year != 2010
keep country year current_basic
rename current_basic fixed_2010_usd
save "$data\2010_fixed_usd_ex_rate.dta", replace
clear
use "$data\ex_rates_for_leverage.dta"
merge n:1 country using "$data\2010_fixed_usd_ex_rate.dta"
drop _merge
sort country year
save "$data\ex_rates_for_leverage.dta", replace
clear

*Isolating US GDP deflator for current PPP scenario
use "$data\ex_rates_for_leverage.dta"
drop if country != "United States"
keep country year GDP_deflator
rename GDP_deflator US_GDP_Deflator
save "$data\US_GDP_Deflator.dta", replace
clear
use "$data\ex_rates_for_leverage.dta"
merge n:1 year using "$data\US_GDP_Deflator.dta"
sort country year
drop _merge
save "$data\ex_rates_for_leverage.dta", replace
clear
*/
	
***** Final Data Set Up - Fig 17   *****
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta"
	merge 1:1 country year using "$data\ex_rates_for_leverage.dta"
	rename _merge _merge_ex
	drop if _merge==2

* Generate new ln Constant GERD (PPP_constant method)
	gen ln_pvt_gerd_constant_ppp_ex = ln(pvt_gerd_LCU_mn/ppp_constant)
	gen ln_pub_gerd_constant_ppp_ex = ln(pub_gerd_LCU_mn/ppp_constant)
	gen ln_ppp_constant = ln(ppp_constant)
	gen uk_ln_pub_gerd_constant_ppp_ex = ln_pub_gerd_constant_ppp_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_ppp_ex = 0 if uk_ln_pub_gerd_constant_ppp_ex == .
	gen oth_ln_pub_gerd_constant_ppp_ex = ln_pub_gerd_constant_ppp_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_ppp_ex = 0 if oth_ln_pub_gerd_constant_ppp_ex == .

* Generate new ln constant GERD (PPP_current method)
	gen ln_pvt_gerd_current_ppp_ex = ln((pvt_gerd_LCU_mn/ppp_current)*(100/US_GDP_Deflator))
	gen ln_pub_gerd_current_ppp_ex = ln((pub_gerd_LCU_mn/ppp_current)*(100/US_GDP_Deflator))
	gen ln_ppp_current = ln(ppp_current)
	gen uk_ln_pub_gerd_current_ppp_ex = ln_pub_gerd_current_ppp_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_current_ppp_ex= 0 if uk_ln_pub_gerd_current_ppp_ex == .
	gen oth_ln_pub_gerd_current_ppp_ex = ln_pub_gerd_current_ppp_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_current_ppp_ex = 0 if oth_ln_pub_gerd_current_ppp_ex == .

* Generate new ln constant GERD (Fixed USD method)
	gen ln_pvt_gerd_fixed_usd_ex = ln((pvt_gerd_LCU_mn/fixed_2010_usd)*(100/GDP_deflator))
	gen ln_pub_gerd_fixed_usd_ex = ln((pub_gerd_LCU_mn/fixed_2010_usd)*(100/GDP_deflator))
	gen ln_fixed_usd_ex = ln(fixed_2010_usd)
	gen uk_ln_pub_gerd_fixed_usd_ex = ln_pub_gerd_fixed_usd_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_fixed_usd_ex= 0 if uk_ln_pub_gerd_fixed_usd_ex == .
	gen oth_ln_pub_gerd_fixed_usd_ex = ln_pub_gerd_fixed_usd_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_fixed_usd_ex = 0 if oth_ln_pub_gerd_fixed_usd_ex == .	

* Generate new ln constant GERD (Current basic method - should be comparable to OE measurement)
	gen ln_pvt_gerd_current_basic_ex = ln((pvt_gerd_LCU_mn/current_basic)*(100/GDP_deflator))
	gen ln_pub_gerd_current_basic_ex = ln((pub_gerd_LCU_mn/current_basic)*(100/GDP_deflator))
	gen ln_current_basic_ex = ln(current_basic) 
	gen uk_ln_pub_gerd_current_basic_ex = ln_pub_gerd_current_basic_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_current_basic_ex= 0 if uk_ln_pub_gerd_current_basic_ex == .
	gen oth_ln_pub_gerd_current_basic_ex = ln_pub_gerd_current_basic_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_current_basic_ex = 0 if oth_ln_pub_gerd_current_basic_ex == .		

* Generate new ln constant GERD (Current Basic method with US GDP deflator)
	gen ln_pvt_gerd_basic_usd_ex = ln((pvt_gerd_LCU_mn/current_basic)*(100/US_GDP_Deflator))
	gen ln_pub_gerd_basic_usd_ex = ln((pub_gerd_LCU_mn/current_basic)*(100/US_GDP_Deflator))
	// Ln exchange rate same as current basic method	
	gen uk_ln_pub_gerd_basic_usd_ex = ln_pub_gerd_basic_usd_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_basic_usd_ex = 0 if uk_ln_pub_gerd_basic_usd_ex == .
	gen oth_ln_pub_gerd_basic_usd_ex = ln_pub_gerd_basic_usd_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_basic_usd_ex = 0 if oth_ln_pub_gerd_basic_usd_ex == .		
	
* Merging deflator
	merge 1:1 year country using "$dta\190121_OECD deflator.dta"
	gen ln_pvt_gerd_constant_GBP_mn = ln(exp(ln_pvt_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	gen ln_pub_gerd_constant_GBP_mn = ln(exp(ln_pub_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	drop if _merge ==2
	xtset country_code year
	
	gen uk_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_GBP_mn = 0 if uk_ln_pub_gerd_constant_GBP_mn == .
	
	gen oth_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_GBP_mn = 0 if oth_ln_pub_gerd_constant_GBP_mn == .

		
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
* Generate LCU with deflators
	gen ln_pvt_gerd_lcu_deflated = ln(pvt_gerd_LCU_mn)*(100/deflator)
	gen ln_pub_gerd_lcu_deflated = ln(pub_gerd_LCU_mn)*(100/deflator)

	gen uk_ln_pub_gerd_lcu_deflated = ln_pub_gerd_lcu_deflated if country == "United Kingdom"
	replace uk_ln_pub_gerd_lcu_deflated = 0 if uk_ln_pub_gerd_lcu_deflated == .
	gen oth_ln_pub_gerd_lcu_deflated = ln_pub_gerd_lcu_deflated if country != "United Kingdom"
	replace oth_ln_pub_gerd_lcu_deflated = 0 if oth_ln_pub_gerd_lcu_deflated == .
	
	
* Correction for interest rates (missing values wrongly coded as zero)
	drop _merge
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year
	
* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020
	
	
	
***** Figure 17 - Regression Analysis  *****	
	
* Figure 17: Model 3 - Original 
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_fig17
		

* PPP Constant Approach		
		xi: xtabond2 ln_pvt_gerd_constant_ppp_ex l.ln_pvt_gerd_constant_ppp_ex	 ///
			uk_ln_pub_gerd_constant_ppp_ex oth_ln_pub_gerd_constant_ppp_ex  ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_ppp_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_ppp_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_ppp_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_ppp_ex] /(1- _b[l.ln_pvt_gerd_constant_ppp_ex] ))
		export_dynamic_panel_fig17	
	
* PPP Constant Approach	with exchange rates
		xi: xtabond2 ln_pvt_gerd_constant_ppp_ex l.ln_pvt_gerd_constant_ppp_ex	 ///
			uk_ln_pub_gerd_constant_ppp_ex oth_ln_pub_gerd_constant_ppp_ex  ///
			d.ln_employment_thousands intrates ln_ppp_constant, ///
			gmm(l.ln_pvt_gerd_constant_ppp_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_ppp_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_ppp_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade ln_ppp_constant) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_ppp_ex] /(1- _b[l.ln_pvt_gerd_constant_ppp_ex] ))
		export_dynamic_panel_fig17	

* PPP Current Approach
		xi: xtabond2 ln_pvt_gerd_current_ppp_ex l.ln_pvt_gerd_current_ppp_ex	 ///
			uk_ln_pub_gerd_current_ppp_ex oth_ln_pub_gerd_current_ppp_ex  ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_current_ppp_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_ppp_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_ppp_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_current_ppp_ex] /(1- _b[l.ln_pvt_gerd_current_ppp_ex] ))
		export_dynamic_panel_fig17	
		
* PPP Current Approach with exchange rates
		xi: xtabond2 ln_pvt_gerd_current_ppp_ex l.ln_pvt_gerd_current_ppp_ex	 ///
			uk_ln_pub_gerd_current_ppp_ex oth_ln_pub_gerd_current_ppp_ex  ///
			d.ln_employment_thousands intrates ln_ppp_current, ///
			gmm(l.ln_pvt_gerd_current_ppp_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_ppp_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_ppp_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade ln_ppp_current) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_current_ppp_ex] /(1- _b[l.ln_pvt_gerd_current_ppp_ex] ))
		export_dynamic_panel_fig17	
		
* Fixed USD Approach
		xi: xtabond2 ln_pvt_gerd_fixed_usd_ex l.ln_pvt_gerd_fixed_usd_ex	 ///
			uk_ln_pub_gerd_fixed_usd_ex oth_ln_pub_gerd_fixed_usd_ex  ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_fixed_usd_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_fixed_usd_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_fixed_usd_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_fixed_usd_ex] /(1- _b[l.ln_pvt_gerd_fixed_usd_ex] ))
		export_dynamic_panel_fig17	
		
* Fixed USD Approach with exchange rates
		xi: xtabond2 ln_pvt_gerd_fixed_usd_ex l.ln_pvt_gerd_fixed_usd_ex	 ///
			uk_ln_pub_gerd_fixed_usd_ex oth_ln_pub_gerd_fixed_usd_ex  ///
			d.ln_employment_thousands intrates ln_fixed_usd_ex, ///
			gmm(l.ln_pvt_gerd_fixed_usd_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_fixed_usd_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_fixed_usd_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade ln_fixed_usd_ex) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_fixed_usd_ex] /(1- _b[l.ln_pvt_gerd_fixed_usd_ex] ))
		export_dynamic_panel_fig17	

* Current Basic Approach
		xi: xtabond2 ln_pvt_gerd_current_basic_ex l.ln_pvt_gerd_current_basic_ex	 ///
			uk_ln_pub_gerd_current_basic_ex oth_ln_pub_gerd_current_basic_ex  ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_current_basic_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_basic_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_basic_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_current_basic_ex] /(1- _b[l.ln_pvt_gerd_current_basic_ex] ))
		export_dynamic_panel_fig17	

* Current Basic Approach with exchange rates
		xi: xtabond2 ln_pvt_gerd_current_basic_ex l.ln_pvt_gerd_current_basic_ex	 ///
			uk_ln_pub_gerd_current_basic_ex oth_ln_pub_gerd_current_basic_ex  ///
			d.ln_employment_thousands intrates ln_current_basic_ex, ///
			gmm(l.ln_pvt_gerd_current_basic_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_basic_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_basic_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade ln_current_basic_ex) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_current_basic_ex] /(1- _b[l.ln_pvt_gerd_current_basic_ex] ))
		export_dynamic_panel_fig17	

* Current Basic Approach with US deflators
		xi: xtabond2 ln_pvt_gerd_basic_usd_ex l.ln_pvt_gerd_basic_usd_ex	 ///
			uk_ln_pub_gerd_basic_usd_ex oth_ln_pub_gerd_basic_usd_ex  ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_basic_usd_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_basic_usd_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_basic_usd_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_basic_usd_ex] /(1- _b[l.ln_pvt_gerd_basic_usd_ex] ))
		export_dynamic_panel_fig17	

* Current Basic Approach with US deflators and exchange rates
		xi: xtabond2 ln_pvt_gerd_basic_usd_ex l.ln_pvt_gerd_basic_usd_ex	 ///
			uk_ln_pub_gerd_basic_usd_ex oth_ln_pub_gerd_basic_usd_ex  ///
			d.ln_employment_thousands intrates ln_current_basic_ex, ///
			gmm(l.ln_pvt_gerd_basic_usd_ex  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_basic_usd_ex  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_basic_usd_ex , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade ln_current_basic_ex) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_basic_usd_ex] /(1- _b[l.ln_pvt_gerd_basic_usd_ex] ))
		export_dynamic_panel_fig17
		
* Local Currency Units Deflated
		xi: xtabond2 ln_pvt_gerd_lcu_deflated l.ln_pvt_gerd_lcu_deflated	 ///
			uk_ln_pub_gerd_lcu_deflated oth_ln_pub_gerd_lcu_deflated  ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_lcu_deflated  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_lcu_deflated  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_lcu_deflated , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_lcu_deflated] /(1- _b[l.ln_pvt_gerd_lcu_deflated] ))
		export_dynamic_panel_fig17
	
* Local Curency units deflated with Exchange rates
		xi: xtabond2 ln_pvt_gerd_lcu_deflated l.ln_pvt_gerd_lcu_deflated	 ///
			uk_ln_pub_gerd_lcu_deflated oth_ln_pub_gerd_lcu_deflated  ///
			d.ln_employment_thousands intrates ln_current_basic_ex, ///
			gmm(l.ln_pvt_gerd_lcu_deflated  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_lcu_deflated  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_lcu_deflated , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade ln_current_basic_ex) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_lcu_deflated] /(1- _b[l.ln_pvt_gerd_lcu_deflated] ))
		export_dynamic_panel_fig17

* Local Curency units deflated with Exchange rates and a constant
		xi: xtabond2 ln_pvt_gerd_lcu_deflated l.ln_pvt_gerd_lcu_deflated	 ///
			uk_ln_pub_gerd_lcu_deflated oth_ln_pub_gerd_lcu_deflated  ///
			d.ln_employment_thousands intrates ln_current_basic_ex, ///
			gmm(l.ln_pvt_gerd_lcu_deflated  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_lcu_deflated  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_lcu_deflated , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade ln_current_basic_ex) ///
			robust orth nodiffsargan
		nlcom( _b[uk_ln_pub_gerd_lcu_deflated] /(1- _b[l.ln_pvt_gerd_lcu_deflated] ))
		export_dynamic_panel_fig17

		
		
////////////////////////////////////////////////////////////////////////////////	

* Preliminaries 
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off
	
	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 070219\"
	global data "$projectfolder\\Data and Tables\Extra data\"
	global dta "$projectfolder\\Data and Tables\Data 070219\"		
		
* Export the Fig20 replication Results
capture program drop export_dynamic_panel_fig20
	program define	export_dynamic_panel_fig20
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Fig20 ex rate sens.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

		
***** Final Data Set Up - Fig 20   *****
	use "$dta\190121_(Q5.5.1)_OECD_for_regressions(NEW).dta"
	merge 1:1 country year using "$data\ex_rates_for_leverage.dta"
	rename _merge _merge_ex
	drop if _merge==2
 
* Generate new ln Constant GERD (PPP_constant method)
	gen ln_pvt_gerd_constant_ppp_ex = ln(pvt_gerd_current_LCU_mn_new/ppp_constant)
	gen ln_pub_gerd_constant_ppp_ex = ln(pub_gerd_current_LCU_mn_new/ppp_constant)
	gen ln_ppp_constant = ln(ppp_constant)
	gen uk_ln_pub_gerd_constant_ppp_ex = ln_pub_gerd_constant_ppp_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_ppp_ex = 0 if uk_ln_pub_gerd_constant_ppp_ex == .
	gen oth_ln_pub_gerd_constant_ppp_ex = ln_pub_gerd_constant_ppp_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_ppp_ex = 0 if oth_ln_pub_gerd_constant_ppp_ex == .

* Generate new ln constant GERD (PPP_current method)
	gen ln_pvt_gerd_current_ppp_ex = ln((pvt_gerd_current_LCU_mn_new/ppp_current)*(100/US_GDP_Deflator))
	gen ln_pub_gerd_current_ppp_ex = ln((pub_gerd_current_LCU_mn_new/ppp_current)*(100/US_GDP_Deflator))
	gen ln_ppp_current = ln(ppp_current)
	gen uk_ln_pub_gerd_current_ppp_ex = ln_pub_gerd_current_ppp_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_current_ppp_ex= 0 if uk_ln_pub_gerd_current_ppp_ex == .
	gen oth_ln_pub_gerd_current_ppp_ex = ln_pub_gerd_current_ppp_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_current_ppp_ex = 0 if oth_ln_pub_gerd_current_ppp_ex == .

* Generate new ln constant GERD (Fixed USD method)
	gen ln_pvt_gerd_fixed_usd_ex = ln((pvt_gerd_current_LCU_mn_new/fixed_2010_usd)*(100/GDP_deflator))
	gen ln_pub_gerd_fixed_usd_ex = ln((pub_gerd_current_LCU_mn_new/fixed_2010_usd)*(100/GDP_deflator))
	gen ln_fixed_usd_ex = ln(fixed_2010_usd)
	gen uk_ln_pub_gerd_fixed_usd_ex = ln_pub_gerd_fixed_usd_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_fixed_usd_ex= 0 if uk_ln_pub_gerd_fixed_usd_ex == .
	gen oth_ln_pub_gerd_fixed_usd_ex = ln_pub_gerd_fixed_usd_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_fixed_usd_ex = 0 if oth_ln_pub_gerd_fixed_usd_ex == .	

* Generate new ln constant GERD (Current basic method - should be comparable to OE measurement)
	gen ln_pvt_gerd_current_basic_ex = ln((pvt_gerd_current_LCU_mn_new/current_basic)*(100/GDP_deflator))
	gen ln_pub_gerd_current_basic_ex = ln((pub_gerd_current_LCU_mn_new/current_basic)*(100/GDP_deflator))
	gen ln_current_basic_ex = ln(current_basic) 
	gen uk_ln_pub_gerd_current_basic_ex = ln_pub_gerd_current_basic_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_current_basic_ex= 0 if uk_ln_pub_gerd_current_basic_ex == .
	gen oth_ln_pub_gerd_current_basic_ex = ln_pub_gerd_current_basic_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_current_basic_ex = 0 if oth_ln_pub_gerd_current_basic_ex == .		

* Generate new ln constant GERD (Current Basic method with US GDP deflator)
	gen ln_pvt_gerd_basic_usd_ex = ln((pvt_gerd_current_LCU_mn_new/current_basic)*(100/US_GDP_Deflator))
	gen ln_pub_gerd_basic_usd_ex = ln((pub_gerd_current_LCU_mn_new/current_basic)*(100/US_GDP_Deflator))
	// Ln exchange rate same as current basic method	
	gen uk_ln_pub_gerd_basic_usd_ex = ln_pub_gerd_basic_usd_ex if country == "United Kingdom"
	replace uk_ln_pub_gerd_basic_usd_ex = 0 if uk_ln_pub_gerd_basic_usd_ex == .
	gen oth_ln_pub_gerd_basic_usd_ex = ln_pub_gerd_basic_usd_ex if country != "United Kingdom"
	replace oth_ln_pub_gerd_basic_usd_ex = 0 if oth_ln_pub_gerd_basic_usd_ex == .		
	
* Conversion to GBP	
	gen pub_gerd_constant_GBP_mn_new = pub_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen pvt_gerd_constant_GBP_mn_new = pvt_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen GDP_constant_GBP_mn  = GDP_constant_USD_mn /ex_rate_perGBP*ex_rate_perusd
	
	gen ln_pub_gerd_constant_GBP_mn_new = ln(pub_gerd_constant_GBP_mn_new)
	gen ln_pvt_gerd_constant_GBP_mn_new = ln(pvt_gerd_constant_GBP_mn_new)
	gen ln_GDP_constant_GBP_mn = ln(GDP_constant_GBP_mn)

* Generating country specific variables
	gen uk_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn_new if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_GBP_mn = 0 if uk_ln_pub_gerd_constant_GBP_mn == .
	
	gen oth_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn_new if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_GBP_mn = 0 if oth_ln_pub_gerd_constant_GBP_mn == .
	
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
* Generate LCU with deflators
	gen ln_pvt_gerd_lcu_deflated = ln(pvt_gerd_current_LCU_mn_new)*(100/deflator)
	gen ln_pub_gerd_lcu_deflated = ln(pub_gerd_current_LCU_mn_new)*(100/deflator)

	gen uk_ln_pub_gerd_lcu_deflated = ln_pub_gerd_lcu_deflated if country == "United Kingdom"
	replace uk_ln_pub_gerd_lcu_deflated = 0 if uk_ln_pub_gerd_lcu_deflated == .
	gen oth_ln_pub_gerd_lcu_deflated = ln_pub_gerd_lcu_deflated if country != "United Kingdom"
	replace oth_ln_pub_gerd_lcu_deflated = 0 if oth_ln_pub_gerd_lcu_deflated == .
	
	
* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020
	
* Generate new and old identifiers
	gen new = 0 
	replace new =1 if pvt_gerd_constant_USD_mn_new != . & pvt_gerd_constant_USD_mn_old == .

	
***** Figure 20 - Regression Analysis  *****	

* Fig 20 - Model 2
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new  ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel_fig20

* PPP Constant Approach		
		xi: xtabond2 ln_pvt_gerd_constant_ppp_ex l.ln_pvt_gerd_constant_ppp_ex  ///
			uk_ln_pub_gerd_constant_ppp_ex oth_ln_pub_gerd_constant_ppp_ex ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_constant_ppp_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_ppp_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_ppp_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_ppp_ex]/(1-_b[l.ln_pvt_gerd_constant_ppp_ex]))
		export_dynamic_panel_fig20

* PPP Constant Approach	with exchange rates
		xi: xtabond2 ln_pvt_gerd_constant_ppp_ex l.ln_pvt_gerd_constant_ppp_ex  ///
			uk_ln_pub_gerd_constant_ppp_ex oth_ln_pub_gerd_constant_ppp_ex ///
			d.ln_employment_na_thousands intrates  ln_ppp_constant, ///
			gmm(l.ln_pvt_gerd_constant_ppp_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_ppp_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_ppp_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ln_ppp_constant) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_ppp_ex]/(1-_b[l.ln_pvt_gerd_constant_ppp_ex]))
		export_dynamic_panel_fig20

* PPP Current Approach
		xi: xtabond2 ln_pvt_gerd_current_ppp_ex l.ln_pvt_gerd_current_ppp_ex  ///
			uk_ln_pub_gerd_current_ppp_ex oth_ln_pub_gerd_current_ppp_ex ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_current_ppp_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_ppp_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_ppp_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_current_ppp_ex]/(1-_b[l.ln_pvt_gerd_current_ppp_ex]))
		export_dynamic_panel_fig20
	
* PPP Current Approach with exchange rates
		xi: xtabond2 ln_pvt_gerd_current_ppp_ex l.ln_pvt_gerd_current_ppp_ex  ///
			uk_ln_pub_gerd_current_ppp_ex oth_ln_pub_gerd_current_ppp_ex ///
			d.ln_employment_na_thousands intrates  ln_ppp_current, ///
			gmm(l.ln_pvt_gerd_current_ppp_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_ppp_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_ppp_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ln_ppp_current) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_current_ppp_ex]/(1-_b[l.ln_pvt_gerd_current_ppp_ex]))
		export_dynamic_panel_fig20
		
* Fixed USD Approach
		xi: xtabond2 ln_pvt_gerd_fixed_usd_ex l.ln_pvt_gerd_fixed_usd_ex  ///
			uk_ln_pub_gerd_fixed_usd_ex oth_ln_pub_gerd_fixed_usd_ex ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_fixed_usd_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_fixed_usd_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_fixed_usd_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_fixed_usd_ex]/(1-_b[l.ln_pvt_gerd_fixed_usd_ex]))
		export_dynamic_panel_fig20

* Fixed USD Approach with exchange rates
		xi: xtabond2 ln_pvt_gerd_fixed_usd_ex l.ln_pvt_gerd_fixed_usd_ex  ///
			uk_ln_pub_gerd_fixed_usd_ex oth_ln_pub_gerd_fixed_usd_ex ///
			d.ln_employment_na_thousands intrates  ln_fixed_usd_ex, ///
			gmm(l.ln_pvt_gerd_fixed_usd_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_fixed_usd_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_fixed_usd_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ln_fixed_usd_ex) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_fixed_usd_ex]/(1-_b[l.ln_pvt_gerd_fixed_usd_ex]))
		export_dynamic_panel_fig20

* Current Basic Approach
		xi: xtabond2 ln_pvt_gerd_current_basic_ex l.ln_pvt_gerd_current_basic_ex  ///
			uk_ln_pub_gerd_current_basic_ex oth_ln_pub_gerd_current_basic_ex ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_current_basic_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_basic_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_basic_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_current_basic_ex]/(1-_b[l.ln_pvt_gerd_current_basic_ex]))
		export_dynamic_panel_fig20
		
* Current Basic Approach with exchange rates
		xi: xtabond2 ln_pvt_gerd_current_basic_ex l.ln_pvt_gerd_current_basic_ex  ///
			uk_ln_pub_gerd_current_basic_ex oth_ln_pub_gerd_current_basic_ex ///
			d.ln_employment_na_thousands intrates  ln_current_basic_ex, ///
			gmm(l.ln_pvt_gerd_current_basic_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_current_basic_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_current_basic_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ln_current_basic_ex) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_current_basic_ex]/(1-_b[l.ln_pvt_gerd_current_basic_ex]))
		export_dynamic_panel_fig20

* Current Basic Approach with US deflators
		xi: xtabond2 ln_pvt_gerd_basic_usd_ex l.ln_pvt_gerd_basic_usd_ex  ///
			uk_ln_pub_gerd_basic_usd_ex oth_ln_pub_gerd_basic_usd_ex ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_basic_usd_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_basic_usd_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_basic_usd_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_basic_usd_ex]/(1-_b[l.ln_pvt_gerd_basic_usd_ex]))
		export_dynamic_panel_fig20
	
* Current Basic Approach with US deflators and exchange rates
		xi: xtabond2 ln_pvt_gerd_basic_usd_ex l.ln_pvt_gerd_basic_usd_ex  ///
			uk_ln_pub_gerd_basic_usd_ex oth_ln_pub_gerd_basic_usd_ex ///
			d.ln_employment_na_thousands intrates  ln_current_basic_ex, ///
			gmm(l.ln_pvt_gerd_basic_usd_ex  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_basic_usd_ex  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_basic_usd_ex , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ln_current_basic_ex) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_basic_usd_ex]/(1-_b[l.ln_pvt_gerd_basic_usd_ex]))
		export_dynamic_panel_fig20
		
* Local Currency Units Deflated
		xi: xtabond2 ln_pvt_gerd_lcu_deflated l.ln_pvt_gerd_lcu_deflated  ///
			uk_ln_pub_gerd_lcu_deflated oth_ln_pub_gerd_lcu_deflated ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_lcu_deflated  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_lcu_deflated  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_lcu_deflated , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_lcu_deflated]/(1-_b[l.ln_pvt_gerd_lcu_deflated]))
		export_dynamic_panel_fig20

* Local Curency units deflated with Exchange rates
		xi: xtabond2 ln_pvt_gerd_lcu_deflated l.ln_pvt_gerd_lcu_deflated  ///
			uk_ln_pub_gerd_lcu_deflated oth_ln_pub_gerd_lcu_deflated ///
			d.ln_employment_na_thousands intrates  ln_current_basic_ex, ///
			gmm(l.ln_pvt_gerd_lcu_deflated  , laglimit(2 1)  coll orth ) ///
			gmm(oth_ln_pub_gerd_lcu_deflated  , laglimit(1 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_lcu_deflated , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  i.decade ln_current_basic_ex) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_lcu_deflated]/(1-_b[l.ln_pvt_gerd_lcu_deflated]))
		export_dynamic_panel_fig20



