********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics (Edited by Joshua Sarracino) *
********************************************************************************

* Preliminaries (defining filepaths)
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off

	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 070219\"
	global dta "$projectfolder\\Data and Tables\Data 070219\"
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Fig20 Correct Lag Structure.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

********************************************************************************
* Use R&D dataset
	use "$dta\190121_(Q5.5.1)_OECD_for_regressions(NEW).dta", clear
	
* Conversion to GBP	
	gen pub_gerd_constant_GBP_mn_new = pub_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen pvt_gerd_constant_GBP_mn_new = pvt_gerd_constant_USD_mn_new/ex_rate_perGBP*ex_rate_perusd
	gen GDP_constant_GBP_mn  = GDP_constant_USD_mn /ex_rate_perGBP*ex_rate_perusd
	
	gen ln_pub_gerd_constant_GBP_mn_new = ln(pub_gerd_constant_GBP_mn_new)
	gen ln_pvt_gerd_constant_GBP_mn_new = ln(pvt_gerd_constant_GBP_mn_new)
	gen ln_GDP_constant_GBP_mn = ln(GDP_constant_GBP_mn)

* Generating country specific variables
	gen uk_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn_new if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_GBP_mn = 0 if uk_ln_pub_gerd_constant_GBP_mn == .
	
	gen oth_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn_new if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_GBP_mn = 0 if oth_ln_pub_gerd_constant_GBP_mn == .
	
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn_new if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn_new if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020
	
* Generate new and old identifiers
	gen new = 0 
	replace new =1 if pvt_gerd_constant_USD_mn_new != . & pvt_gerd_constant_USD_mn_old == .
		
********************************************************************************

		
* Fig 19 - Model 1							
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_na_thousands intrates , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new  , laglimit(1 3)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(2 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(2 5)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 4)  coll orth ) ///
			iv(intrates ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel
			
* Fig 19 - Model 2
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new  ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_na_thousands intrates  , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new  , laglimit(1 3)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(2 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(2 5)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 4)  coll orth ) ///
			iv(intrates  i.decade) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel
	
* Fig 19 - Model 3
		xi: xtabond2 ln_pvt_gerd_constant_GBP_mn_new l.ln_pvt_gerd_constant_GBP_mn_new ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_na_thousands intrates , ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn_new  , laglimit(1 3)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(2 3)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(2 3)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 3)  coll orth ) ///
			iv(intrates  ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_GBP_mn]/(1-_b[l.ln_pvt_gerd_constant_GBP_mn_new]))
		export_dynamic_panel
		
* Fig 19 - Model 4
		xi: xtabond2 ln_pvt_gerd_constant_USD_mn_new l.ln_pvt_gerd_constant_USD_mn_new ///
			uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_na_thousands intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn_new  , laglimit(1 3)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(2 5)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(2 5)  coll orth ) ///
			gmm(d.ln_employment_na_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates  ) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn_new]))
		export_dynamic_panel
