********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics (Edited by Joshua Sarracino) *
********************************************************************************

* Preliminaries (defining filepaths)
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off

	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 070219\"
	global dta "$projectfolder\\Data and Tables\Data 070219\"
	
********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	
* Merging deflator
	merge 1:1 year country using "$dta\190121_OECD deflator.dta"
	gen ln_pvt_gerd_constant_GBP_mn = ln(exp(ln_pvt_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	gen ln_pub_gerd_constant_GBP_mn = ln(exp(ln_pub_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	drop if _merge ==2
	xtset country_code year
	
	gen uk_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_GBP_mn = 0 if uk_ln_pub_gerd_constant_GBP_mn == .
	
	gen oth_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_GBP_mn = 0 if oth_ln_pub_gerd_constant_GBP_mn == .

		
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
* Correction for interest rates (missing values wrongly coded as zero)
	drop _merge
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year
	
* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Fig17_alternative_runs_all.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end
	
* Code to export results
	capture program drop export_dynamic_panel_IV
	program define	export_dynamic_panel_IV
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Fig17_IV_loop.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end	
	
********************************************************************************

/* Variable List to run 

1. General Economic Environment
A - GDP and GDP Growth
B - Employment and Employment Growth
D - Capital Stock and Growth of Capital Stock and GFCF
F - Inventory

2. Competition
H - HHI 

3. Workers skills and knowledge
E - QALI and Tertiary Education and Compensation of Employees
J - R&D Personnel and Growth of R&D personnel

4. International Trade
G - Exchange Rate 
I - Exports as a percentage of GDP

K - Scientific Articles

C - Patents and Patent Growth
L - Charges for IP use

*/

********************************************************************************

*Original Regressions
* Figure 17: Model 1
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
* Figure 17: Model 2							
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan nocons 	
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
			
* Figure 17: Model 3
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth nodiffsargan nocons
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
* Figure 17: Model 4
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		export_dynamic_panel

		
/*******************************************************************************

The following section of code contains runs of figure 17 that are completed 		
using other variables. The split has been done in four ways across similar types
of variable. For example, general economic conditions involve various things and 
we do not model more than one of these for fear of mulitcollinearity. 

The structure is rather messy and inconvienent to quickly check through but when
all checks have been made, I intend to export these into a excel file which will
be easier to read. 

*******************************************************************************/

/*  Test code to check loop works with simple OLS
foreach var in ln_inventory_change_constantUSD ln_employment_thousands {
regress ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
	uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
	`var'
}					*/
	
foreach var in ln_GDP_constant_USD_mn d.ln_GDP_constant_USD_mn ///
	ln_employment_thousands d.ln_employment_thousands ///
	ln_patents d.ln_patents ///
	ln_capitalstock_2005USDm d.ln_capitalstock_2005USDm ///
	ln_QALI d.ln_QALI ///
	ln_ex_rate_perusd d.ln_ex_rate_perusd ///
	ln_scientific_articles d.ln_scientific_articles ///
	ln_charges_for_IP_use_currentUSD d.ln_charges_for_IP_use_currentUSD ///
	ln_COE_constant_USD_mn d.ln_COE_constant_USD_mn ///
	ln_inventory_change_constantUSD d.ln_inventory_change_constantUSD ///
	ln_GFCF_constant_USD_mn d.ln_GFCF_constant_USD_mn ///
	ln_HHI ///
	tertiaryedu_labourforceshare d.tertiaryedu_labourforceshare ///
	RandDpersonnel_per000employment d.RandDpersonnel_per000employment ///
	venture_capital_inv_share_GDP d.venture_capital_inv_share_GDP {
	
	* Figure 17: Model 1
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			`var' intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(`var' , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth 
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
* Figure 17: Model 2							
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			`var' intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(`var' , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth 	
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
			
* Figure 17: Model 3
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			`var' intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(1 5)  coll orth ) ///
			gmm(`var' , laglimit(1 1)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth 
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
		
* Figure 17: Model 4
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			`var' intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(`var' , laglimit(1 5)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		nlcom(_b[uk_ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		export_dynamic_panel
		
}



foreach var in ln_GDP_constant_USD_mn d.ln_GDP_constant_USD_mn ///
	ln_employment_thousands d.ln_employment_thousands ///
	ln_patents d.ln_patents ///
	ln_capitalstock_2005USDm d.ln_capitalstock_2005USDm ///
	ln_QALI d.ln_QALI ///
	ln_ex_rate_perusd d.ln_ex_rate_perusd ///
	ln_scientific_articles d.ln_scientific_articles ///
	ln_charges_for_IP_use_currentUSD d.ln_charges_for_IP_use_currentUSD ///
	ln_COE_constant_USD_mn d.ln_COE_constant_USD_mn ///
	ln_inventory_change_constantUSD d.ln_inventory_change_constantUSD ///
	ln_GFCF_constant_USD_mn d.ln_GFCF_constant_USD_mn ///
	ln_HHI ///
	tertiaryedu_labourforceshare d.tertiaryedu_labourforceshare ///
	RandDpersonnel_per000employment d.RandDpersonnel_per000employment ///
	venture_capital_inv_share_GDP d.venture_capital_inv_share_GDP {
		
	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			`var' intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , lag(1 2) coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(2 4)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(2 4)  coll orth ) ///
			iv(`var' intrates) ///
			robust orth 
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_IV
		
	xi: xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			`var' intrates, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn  , lag(1 2) coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(2 4)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(2 4)  coll orth ) ///
			iv(`var' intrates i.decade) ///
			robust orth 
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel_IV		
		
		
		}
	
	
* Figure 17: Model XX							
		xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates d.tertiaryedu_labourforceshare, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(2 4)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(2 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 3)  coll orth ) ///
			gmm(d.tertiaryedu_labourforceshare , laglimit(1 3)  coll orth ) ///
			iv(intrates) ///
			robust orth 	
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
			
* Figure 17: Model XX
	xi: 	xtabond2 ln_pvt_gerd_constant_GBP_mn l.ln_pvt_gerd_constant_GBP_mn ///
			uk_ln_pub_gerd_constant_GBP_mn oth_ln_pub_gerd_constant_GBP_mn ///
			d.ln_employment_thousands intrates d.tertiaryedu_labourforceshare, ///
			gmm(l.ln_pvt_gerd_constant_GBP_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_GBP_mn  , laglimit(2 4)  coll orth ) ///
			gmm(uk_ln_pub_gerd_constant_GBP_mn , laglimit(2 3)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) ///
			gmm(d.tertiaryedu_labourforceshare , laglimit(1 3)  coll orth ) ///
			iv(intrates i.decade) ///
			robust orth 	
		nlcom( _b[uk_ln_pub_gerd_constant_GBP_mn] /(1- _b[l.ln_pvt_gerd_constant_GBP_mn] ))
		export_dynamic_panel
	
	
	
	
	