********************************************************************************
****************** 		BEIS Stationarity analysis 		    ********************
******************     		Date: 25/02/2019                ********************
****************** 			Joshua Sarracino                ********************
********************************************************************************

* Preliminaries 
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off
	
	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 070219\"
	global data "$projectfolder\\Data and Tables\Extra data\"
	global dta "$projectfolder\\Data and Tables\Data 070219\"
	
	* Export the Fig17 trimmed Results
capture program drop export_dynamic_panel_fig17
	program define	export_dynamic_panel_fig17
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Fig17 stationarity testing.xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

	

*** Trim the Data down
use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta"	

	* Keep countries with 11 or more usable observations between 1992 and 2015
	* Restrict sample: 
	keep if year<=2015 & year>=1992
	drop if country=="Australia" | country=="Chile" | country=="Denmark" | country=="Greece" | country=="Iceland" | country=="Luxembourg" | country=="New Zealand" | country=="Norway"

	merge 1:1 year country using "$dta\190121_OECD deflator.dta"
	gen ln_pvt_gerd_constant_GBP_mn = ln(exp(ln_pvt_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	gen ln_pub_gerd_constant_GBP_mn = ln(exp(ln_pub_gerd_constant_USD_mn)*CPI/deflator*ex_rate_perusd/ ex_rate_perGBP)
	drop if _merge ==2
	xtset country_code year
	
	gen uk_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_GBP_mn = 0 if uk_ln_pub_gerd_constant_GBP_mn == .
	
	gen oth_ln_pub_gerd_constant_GBP_mn = ln_pub_gerd_constant_GBP_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_GBP_mn = 0 if oth_ln_pub_gerd_constant_GBP_mn == .

		
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
* Correction for interest rates (missing values wrongly coded as zero)
	drop _merge
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year
	
* Generate decades
	generate 	decade = "pre-1960s" if year <1960
	replace		decade = "1960s" if year > = 1960 & year < 1970
	replace		decade = "1970s" if year > = 1970 & year < 1980
	replace		decade = "1980s" if year > = 1980 & year < 1990
	replace		decade = "1990s" if year > = 1990 & year < 2000
	replace		decade = "2000s" if year > = 2000 & year < 2010
	replace		decade = "2010s" if year > = 2010 & year < 2020	
	
********************************************************************************	

* Stationarity Testing	
	xtline ln_pub_gerd_constant_GBP_mn
	graph export "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data and Tables\Graphs\xtline public.pdf", as(pdf) replace
	xtline ln_pvt_gerd_constant_GBP_mn
	graph export "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data and Tables\Graphs\xtline public.pdf", as(pdf) replace

	
	xtunitroot fisher ln_pvt_gerd_constant_GBP_mn, dfuller lags(1)
	xtunitroot fisher ln_pvt_gerd_constant_GBP_mn, dfuller trend lags(1)
	xtunitroot fisher ln_pvt_gerd_constant_GBP_mn, dfuller lags(2)
	xtunitroot fisher ln_pvt_gerd_constant_GBP_mn, dfuller trend lags(2)	
	
	xtunitroot fisher ln_pub_gerd_constant_GBP_mn, dfuller lags(1)
	xtunitroot fisher ln_pub_gerd_constant_GBP_mn, dfuller trend lags(1)
	xtunitroot fisher ln_pub_gerd_constant_GBP_mn, dfuller lags(2)
	xtunitroot fisher ln_pub_gerd_constant_GBP_mn, dfuller trend lags(2)	
