********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off
	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 301018\"
	global dta "$projectfolder\\Data and Tables\Data 301018\"
********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .

* Correction for interest rates (missing values wrongly coded as zero)
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year
	
********************************************************************************
* Dynamic panel - 0								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 	
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
			
	* Saving the results
		outreg2 using "$tables\\5_5_1_OECD_panel(20180815)- UK-time_sens.xls", dec(4) replace ///
			ctitle(Dynamic Panel - 1) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
			
forvalues i = 0/3 {

* Dynamic panel - 1								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			l`i'.uk_ln_pub_gerd_constant_USD_mn l`i'.oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			gmm(l`i'.oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l`i'.uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 	
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
			
	* Saving the results
		outreg2 using "$tables\\5_5_1_OECD_panel(20180815)- UK-time_sens.xls", dec(4) append ///
			ctitle(Dynamic Panel - 1 - with `i' lag) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
			
* Dynamic panel - 2								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			l`i'.uk_ln_pub_gerd_constant_USD_mn l`i'.oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(l`i'.oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(l`i'.uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		
	* Saving the results
		outreg2 using "$tables\\5_5_1_OECD_panel(20180815)- UK-time_sens.xls", dec(4) append ///
			ctitle(Dynamic Panel - 2 - with `i' lag) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
			
* Dynamic panel - 3								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  ///
			l`i'.uk_ln_pub_gerd_constant_USD_mn l`i'.oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ln_ex_rate_perusd, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(l`i'.oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(l`i'.uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates ln_ex_rate_perusd) ///
			robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
		
	* Saving the results
	outreg2 using "$tables\\5_5_1_OECD_panel(20180815)- UK-time_sens.xls", dec(4) append ///
			ctitle(Dynamic Panel - 3 - with `i' lag) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
}
