********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics							   *
********************************************************************************

* Preliminaries (defining filepaths)
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off
	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 301018\"
	global dta "$projectfolder\\Data and Tables\Data 301018\"

********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	
* Correction for interest rates (missing values wrongly coded as zero)
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	xtset country_code year
	replace country = "South Korea" if country == "Korea"
	
********************************************************************************
* Dynamic panel - 1								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) replace ///
			ctitle(Dynamic Panel - 1) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 2								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			ln_GDP_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(ln_GDP_constant_USD_mn, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 2) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 3								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(ln_employment_thousands, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 3) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 4								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			iv(intrates ln_employment_thousands) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 4) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 5								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			iv(intrates ln_employment_thousands) ///
			robust orth nodiffsargan noleveleq

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 5) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 6								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 3)  coll orth ) ///
			iv(intrates ln_employment_thousands) ///
			robust orth nodiffsargan noleveleq
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 6) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')

* Dynamic panel - 7								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 7) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')

* Dynamic panel - 8								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 8) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')

* Dynamic panel - 9								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 93) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 10								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 10) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 11								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ln_patents, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands ln_patents, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 11) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 12								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ln_capitalstock_2005USDm, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands ln_capitalstock_2005USDm, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 12) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 13								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ln_QALI, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_employment_thousands ln_QALI, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 13) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 14								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ln_ex_rate_perusd, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates ln_ex_rate_perusd) ///
			robust orth nodiffsargan 
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 14) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 15								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ln_inventory_change_constantUSD, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates ln_inventory_change_constantUSD) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 15) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 16								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 1)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(3 3)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

					local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 16) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 17								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 17) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 18								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 3)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 18) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 19								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates ln_patents, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn ln_patents, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 19) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 20								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates ln_capitalstock_2005USDm, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn ln_capitalstock_2005USDm, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 20) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 21								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates ln_QALI, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn ln_QALI, laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 21) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 22								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates ln_ex_rate_perusd, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(3 3)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(2 2)  coll orth ) ///
			iv(intrates ln_ex_rate_perusd) ///
			robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 21) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 23								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates ln_inventory_change_constantUSD, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(intrates ln_inventory_change_constantUSD) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 23) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')

* Dynamic panel - 24								
		gen sq_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn^2
		replace sq_ln_pub_gerd_constant_USD_mn = 0 if sq_ln_pub_gerd_constant_USD_mn == .
		
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			sq_ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  sq_ln_pub_gerd_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 24) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')

* Dynamic panel - 25								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates [pw=pub_gerd_constant_USD_mn], ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 25) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 26								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates [pw=GDP_constant_USD_mn], ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 26) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 27								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GFCF_constant_USD_mn intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_GFCF_constant_USD_mn , laglimit(1 4)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 27) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 28								
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) ///
			iv(intrates HHI) ///
			robust orth nodiffsargan 

		
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 28) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
				
* Dynamic panel - 29								
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI ln_ex_rate_perusd, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) ///
			iv(intrates HHI ln_ex_rate_perusd) ///
			robust orth nodiffsargan 

		
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 29) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 30								
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI exports_GDPshare, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) ///
			iv(intrates HHI exports_GDPshare) ///
			robust orth nodiffsargan 

		
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 30) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')

* Dynamic panel - 30								
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_COE_constant_USD_mn intrates HHI exports_GDPshare, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_COE_constant_USD_mn , laglimit(1 4)  coll orth ) ///
			iv(intrates HHI exports_GDPshare) ///
			robust orth nodiffsargan 

		
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 30) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 31							
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			l.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn l.ln_pub_gerd_constant_USD_mn , laglimit(3 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(2 4)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		
		*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
		*	d.ln_GDP_constant_USD_mn intrates , ///
		*	gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
		*	gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
		*	iv(l.d.ln_GDP_constant_USD_mn ) ///
		*	robust orth nodiffsargan 
			
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 31) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 32							
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			l2.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn l2.ln_pub_gerd_constant_USD_mn , laglimit(4 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(3 4)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		
		*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
		*	d.ln_GDP_constant_USD_mn intrates , ///
		*	gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
		*	gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
		*	iv(l.d.ln_GDP_constant_USD_mn ) ///
		*	robust orth nodiffsargan 
			
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 31) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')

* Dynamic panel - 31							
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  ///
			l.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  l.ln_pub_gerd_constant_USD_mn , laglimit(3 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(2 4)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		
		*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
		*	d.ln_GDP_constant_USD_mn intrates , ///
		*	gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
		*	gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
		*	iv(l.d.ln_GDP_constant_USD_mn ) ///
		*	robust orth nodiffsargan 
			
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 31) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 34							
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  ///
			l2.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  l2.ln_pub_gerd_constant_USD_mn , laglimit(4 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(3 4)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		
		*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
		*	d.ln_GDP_constant_USD_mn intrates , ///
		*	gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
		*	gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
		*	iv(l.d.ln_GDP_constant_USD_mn ) ///
		*	robust orth nodiffsargan 
			
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 34) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
			
* Dynamic panel - 35							
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  ///
			l3.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  l3.ln_pub_gerd_constant_USD_mn , laglimit(4 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(3 4)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 

		
		*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
		*	d.ln_GDP_constant_USD_mn intrates , ///
		*	gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
		*	gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
		*	iv(l.d.ln_GDP_constant_USD_mn ) ///
		*	robust orth nodiffsargan 
			
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\Q5_5_1_OECD_panel(20180815).xls", dec(4) append ///
			ctitle(Dynamic Panel - 35) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			long-run impact, `ltcoeff', p-value, `pvalue')
