********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 						Author:  Oxford Economics (Edited by Joshua Sarracino) *
********************************************************************************

* Preliminaries (defining filepaths)
	sysdir set PLUS "L:\StataLib\ado\plus"

	clear
	set more off
	capture log close

	global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
	global tables "$projectfolder\\Data and Tables\Tables 301018\"
	global dta "$projectfolder\\Data and Tables\Data 301018\"
	global temp	"$projectfolder\\Data and Tables\Data 301018\temp\"
	
* Code to export results
	capture program drop export_dynamic_panel
	program define	export_dynamic_panel
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

		* Saving the results
		outreg2 using "$tables\\Q5_3_3a_OECD panel (BERD and HERD).xls", dec(4) append ///
			ctitle(Dynamic Panel) ///
			addstat(Number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp')
	end

********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5_3_1_GERD and HERD panel_for_reg.dta", clear
	
	gen uk_ln_pub_herd_constant_USD_mn = ln_pub_herd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_herd_constant_USD_mn = 0 if uk_ln_pub_herd_constant_USD_mn == .
	
	gen oth_ln_pub_herd_constant_USD_mn = ln_pub_herd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_herd_constant_USD_mn = 0 if oth_ln_pub_herd_constant_USD_mn == .

* Correction for interest rates (missing values wrongly coded as zero)
	rename intrates intrates_old
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	drop _merge
	xtset country_code year

* Preparing GERD data
	preserve 
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
	keep year country  pub_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  uk_ln_pub_gerd_constant_USD_mn uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn
	save "$temp\GERD to merge with (Q5.5.1)_OECD_for_regressions.dta", replace
	restore

* Preparing BERD data
	preserve 
	use "$dta\180730_(Q5_3_2_BERD and GERD panel_for_reg.dta", clear
	gen uk_ln_pub_berd_constant_USD_mn = ln_pub_berd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_berd_constant_USD_mn = 0 if uk_ln_pub_berd_constant_USD_mn == .
	
	gen oth_ln_pub_berd_constant_USD_mn = ln_pub_berd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_berd_constant_USD_mn = 0 if oth_ln_pub_berd_constant_USD_mn == .
	
	keep year country  pub_berd_constant_USD_mn ln_pub_berd_constant_USD_mn  uk_ln_pub_berd_constant_USD_mn uk_ln_pub_berd_constant_USD_mn oth_ln_pub_berd_constant_USD_mn
	save "$temp\BERD to merge with (Q5.3.1)_OECD_for_regressions.dta", replace
	restore

* Merging GERD
	merge 1:1 year country using "$temp\GERD to merge with (Q5.5.1)_OECD_for_regressions.dta"
	drop if _merge != 3
	drop _merge

* Merging BERD
	merge 1:1 year country using "$temp\BERD to merge with (Q5.3.1)_OECD_for_regressions.dta"
	drop if _merge != 3
	drop _merge
	
	drop if ln_pub_gerd_constant_USD_mn == 0 & ln_pub_herd_constant_USD_mn == 0
	
	xtset country_code year
	
	gen pub_oth_gerd_constant_USD_mn = pub_gerd_constant_USD_mn - pub_herd_constant_USD_mn - pub_berd_constant_USD_mn 
	gen ln_pub_oth_gerd_constant_USD_mn = ln(pub_oth_gerd_constant_USD_mn)
			
* Save
	save "$dta\180730_(Q5_3_1and2_BERD and HERD panel_for_reg.dta", replace
********************************************************************************
* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel

* Dynamic panel - 2
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(1 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel

* Dynamic panel - 3
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(1 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 4
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 5
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			ln_GDP_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 6
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_GVA_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GVA_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 7
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_capitalstock_2005USDm intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_capitalstock_2005USDm , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
		
* Dynamic panel - 8
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_GFCF_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GFCF_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 9
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_inventory_change_constantUSD intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_inventory_change_constantUSD , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 10
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates  ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands  , laglimit(1 6)  coll  ) ///
			iv(intrates HHI) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 11
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI ln_ex_rate_perusd ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands HHI , laglimit(1 6)  coll  ) ///
			iv(intrates ln_ex_rate_perusd) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 12
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI exports_GDPshare ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands HHI , laglimit(1 6)  coll  ) ///
			iv(intrates exports_GDPshare) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 13
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_COE_constant_USD_mn intrates HHI exports_GDPshare ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_COE_constant_USD_mn HHI , laglimit(1 6)  coll  ) ///
			iv(intrates exports_GDPshare) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 14
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_QALI intrates HHI exports_GDPshare ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_QALI HHI , laglimit(1 6)  coll  ) ///
			iv(intrates exports_GDPshare) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 15
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel

* Dynamic panel - 15
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn   , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 3) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(2 3)  coll  ) ///  
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 1b
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn , laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
	export_dynamic_panel
	
* Dynamic panel - 2b
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(1 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
	
