********************************************************************************
*	 		Relationship between public and private R&D spending 			   *
* 					Author:  Oxford Economics (Edited by Armand Viaje-Balog)   *
* 						Date created: 26 July 2018							   *
********************************************************************************

* Preliminaries (defining filepaths)
	clear 
	set more off

global projectfolder "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\"
global tables "$projectfolder\\Data and Tables\Tables 070219\"
global dta "$projectfolder\\Data and Tables\Data 070219\"

********************************************************************************
* Use R&D dataset
	use "$dta\180730_(Q5.5.1)_OECD_for_regressions.dta", clear
	
	gen esp_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "Spain"
	replace esp_ln_pub_gerd_constant_USD_mn = 0 if esp_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "Spain"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .

* Correction for interest rates (missing values wrongly coded as zero)
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "$dta\OECD_interestrates.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year

********************************************************************************
* Dynamic panel - 1								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			esp_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(esp_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 	
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[esp_ln_pub_gerd_constant_USD_mn] - _b[oth_ln_pub_gerd_constant_USD_mn])
		
		matrix b = r(b)
		matrix V = r(V)
		local diff_ESPvsRoW = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\5_5_1_OECD_panel(20180815)- ESP.xls", dec(4) replace ///
			ctitle(Dynamic Panel - 1) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			Diff - ESP v RoW, `diff_ESPvsRoW', p-value, `pvalue')
			
* Dynamic panel - 8								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			esp_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) ///
			gmm(esp_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) ///
			iv(intrates) ///
			robust orth nodiffsargan 		
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
	nlcom (_b[esp_ln_pub_gerd_constant_USD_mn] - _b[oth_ln_pub_gerd_constant_USD_mn])
		
		matrix b = r(b)
		matrix V = r(V)
		local diff_ESPvsRoW = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
		outreg2 using "$tables\\5_5_1_OECD_panel(20180815)- ESP.xls", dec(4) append ///
			ctitle(Dynamic Panel - 8) ///
			addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			Diff - ESP v RoW, `diff_ESPvsRoW', p-value, `pvalue')
	
* Dynamic panel - 14								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  ///
			esp_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ln_ex_rate_perusd, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) ///
			gmm(esp_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) ///
			gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) ///
			iv(intrates ln_ex_rate_perusd) ///
			robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
	nlcom (_b[esp_ln_pub_gerd_constant_USD_mn] - _b[oth_ln_pub_gerd_constant_USD_mn])
		
		
		matrix b = r(b)
		matrix V = r(V)
		local diff_ESPvsRoW = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	* Saving the results
	outreg2 using "$tables\\5_5_1_OECD_panel(20180815)- ESP.xls", dec(4) append ///
			ctitle(Dynamic Panel - 14) 
			///
			*addstat(number of instruments, `instru', AR2 p-value, `AR2stat', ///
			*Sargan p-value, `sarganp', Hansen p-value, `hansenp', ///
			*Diff - ESP v RoW, `diff_ESPvsRoW', p-value, `pvalue')
			
