sysdir set PLUS "L:\StataLib\ado\plus"

clear

set more off

capture log close



cd "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data\Panel Data"

log using Panel_Outputs.txt, replace text

local path W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data\Panel Data

sysdir set PLUS "L:\StataLib\ado\plus"

///////            Data set up          ///////
{
*Base data file for a lot of the panel analysis
*use "`path'/180730_(Q5.5.1)_OECD_for_regressions_v13.dta"
use "`path'/180730_(Q5.5.1)_OECD_for_regressions_v13_new_ex.dta"

rename hhi HHI

*They include a correction for interest rates where values are incorrectly zero
rename intrates intrates_old   // reasoning not to clash new and old terms
replace country = "Korea" if country=="South Korea" // Consistency with merge file
merge 1:1 year country using "OECD_interestrates_v13.dta" // merge exact same based on country and year
drop if _merge==2  // drop any values new from the interest rate file
xtset country_code year // Set up panel set
replace country = "South Korea" if country =="Korea"  // reset the naming convention
}
 
 xtabond2 ln_pvt_gerd_constant_new_ex l.ln_pvt_gerd_constant_new_ex ln_pub_gerd_constant_new_ex intrates ln_ex_rate, gmm(l.ln_pvt_gerd_constant_new_ex ln_pub_gerd_constant_new_ex , laglimit(1 2)  coll orth ) iv(intrates ln_ex_rate) robust orth nodiffsargan
 
 xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn intrates ln_ex_rate_perusd, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) iv(intrates ln_ex_rate_perusd) robust orth nodiffsargan 
 
 local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
 
 outreg2 using "`path'/new_ex_rates.xls", dec(4) replace ctitle(New Ex) addstat(number of instruments, `instru', AR2 p-value, `AR2stat', Sargan p-value, `sarganp', Hansen p-value, `hansenp')
 
 
 ********  Models from 180917_Q5_5_1_OECD leverage panel (Dynamic panel)
 
//    Model 1 - corresponds with Figure 20 Column 2    // 
{ 
xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn intrates , gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 
/* Regression runs private gerd on a constant, the lag of itself, public gerd 
and interest rates. Results indicate significant role of all three three 
variables on the output. */

local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)

outreg2 using "`path'/diff_ex_rates.xls", dec(4) replace ctitle(New Ex) addstat(number of instruments, `instru', AR2 p-value, `AR2stat', Sargan p-value, `sarganp', Hansen p-value, `hansenp')
 
// Stores outputs of the model such as the AR2M sargan and Hansen test statistics.	
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
// nlcom estimates the ratio here between the coefficient on the public gerd input and one minus the lagged private gerd input. The indication is that long-run impacts are 0.753.
				
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
// Store further statistics such as the std error, the z value and the pvalue of the output

	
// Outreg2 commands have been ignored for the time being	
	
	
	
}
	
	
	
	

	
//    Model 2 - corresponds with Figure 20 Column 3    // 
{
xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ln_GDP_constant_USD_mn intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(ln_GDP_constant_USD_mn, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
}

			
//    Model 3 - corresponds with Figure 20 Column 4    // 								
{		
xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(ln_employment_thousands, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 4 - Not included in the Analysis          // 								
{		
xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) iv(intrates ln_employment_thousands) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}
			
//    Model 5 - Not included in the Analysis           // 								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) iv(intrates ln_employment_thousands) robust orth nodiffsargan noleveleq

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}
			
//    Model 6 - Not included in the Analysis           // 								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 3)  coll orth ) iv(intrates ln_employment_thousands) robust orth nodiffsargan noleveleq
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}

//    Model 7 - corresponds with Figure 20 Column 5    // 								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(d.ln_GDP_constant_USD_mn, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}

//    Model 8 - corresponds with Figure 20 Column 6    // 								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) iv(intrates) robust orth nodiffsargan 
	
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}
	
//    Model 9 - Not included in the Analysis            // 								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 10 - Not included in the Analysis            // 								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}
			
//    Model 11 - Not included in the Analysis           // 								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates ln_patents, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(d.ln_employment_thousands ln_patents, laglimit(1 2)  coll orth )iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 12 - Not included in the Analysis           //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates ln_capitalstock_2005USDm, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(d.ln_employment_thousands ln_capitalstock_2005USDm, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
}
			
//    Model 13 - corresponds with Figure 20 Column 7    //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates ln_QALI, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(d.ln_employment_thousands ln_QALI, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 14 - corresponds with Figure 20 Column 10    //							
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates ln_ex_rate_perusd, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) iv(intrates ln_ex_rate_perusd) robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 15 - corresponds with Figure 20 Column 11    //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates ln_inventory_change_constantUSD, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) iv(intrates ln_inventory_change_constantUSD) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}
			
//    Model 16 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 1)  coll orth ) gmm(d.ln_GDP_constant_USD_mn , laglimit(3 3)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 17 - Not included in the Analysis            //							
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 18 - Not included in the Analysis            //							
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 3)  coll orth ) gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
}
			
//    Model 19 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates ln_patents, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(d.ln_GDP_constant_USD_mn ln_patents, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	}
			
//    Model 20 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates ln_capitalstock_2005USDm, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(d.ln_GDP_constant_USD_mn ln_capitalstock_2005USDm, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 21 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates ln_QALI, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(d.ln_GDP_constant_USD_mn ln_QALI, laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 22 - Not included in the Analysis            //							
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates ln_ex_rate_perusd, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(3 3)  coll orth ) gmm(d.ln_GDP_constant_USD_mn , laglimit(2 2)  coll orth ) iv(intrates ln_ex_rate_perusd) robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 23 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GDP_constant_USD_mn intrates ln_inventory_change_constantUSD, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) iv(intrates ln_inventory_change_constantUSD) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}

//    Model 24 - Not included in the Analysis            //								
{
		gen sq_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn^2
		replace sq_ln_pub_gerd_constant_USD_mn = 0 if sq_ln_pub_gerd_constant_USD_mn == .
		
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn sq_ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  sq_ln_pub_gerd_constant_USD_mn , laglimit(1 2)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}

//    Model 25 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates [pw=pub_gerd_constant_USD_mn], gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 26 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates [pw=GDP_constant_USD_mn], gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) iv(intrates) robust orth nodiffsargan 

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 27 - Not included in the Analysis            //								
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_GFCF_constant_USD_mn intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_GFCF_constant_USD_mn , laglimit(1 4)  coll orth ) iv(intrates) robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 28 - corresponds with Figure 20 Column 8    //							
{
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates HHI, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) iv(intrates HHI) robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
				
//    Model 29 - Not included in the Analysis            //								
{
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates HHI ln_ex_rate_perusd, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) iv(intrates HHI ln_ex_rate_perusd) robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}	
		
//    Model 30 - corresponds with Figure 20 Column 9    //							
{
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates HHI exports_GDPshare, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 4)  coll orth ) iv(intrates HHI exports_GDPshare) robust orth nodiffsargan 	
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}

//    Model 31 - Not included in the Analysis            //								
{
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn d.ln_COE_constant_USD_mn intrates HHI exports_GDPshare, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(d.ln_COE_constant_USD_mn , laglimit(1 4)  coll orth ) iv(intrates HHI exports_GDPshare) robust orth nodiffsargan	
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 32 - Not included in the Analysis            //						
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn l.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn l.ln_pub_gerd_constant_USD_mn , laglimit(3 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(2 4)  coll orth ) iv(intrates) robust orth nodiffsargan 

		
		/*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(l.d.ln_GDP_constant_USD_mn ) ///
			robust orth nodiffsargan */

		// Unsure what this model would return - J
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 33 - Not included in the Analysis            //							
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn l2.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn l2.ln_pub_gerd_constant_USD_mn , laglimit(4 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(3 4)  coll orth ) iv(intrates) robust orth nodiffsargan 

		/*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(l.d.ln_GDP_constant_USD_mn ) ///
			robust orth nodiffsargan  */
		
		// Unsure what this model would return - J
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
//    Model 34 - Not included in the Analysis            //							
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  l.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn  l.ln_pub_gerd_constant_USD_mn , laglimit(3 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(2 4)  coll orth ) iv(intrates) robust orth nodiffsargan 
		
		/*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(l.d.ln_GDP_constant_USD_mn ) ///
			robust orth nodiffsargan */
		
	// Unsure what this model would return - J
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[l.ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 35 - Not included in the Analysis            //						
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  l2.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn  l2.ln_pub_gerd_constant_USD_mn , laglimit(4 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(3 4)  coll orth ) iv(intrates) robust orth nodiffsargan 
		
		/*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(l.d.ln_GDP_constant_USD_mn ) ///
			robust orth nodiffsargan */
			
// Unsure what this model would return - J	

		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[l2.ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}
			
//    Model 36 - Not included in the Analysis            //						
{
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  l3.ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn  l3.ln_pub_gerd_constant_USD_mn , laglimit(4 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(3 4)  coll orth ) iv(intrates) robust orth nodiffsargan 

		
		/*xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 2)  coll orth ) ///
			iv(l.d.ln_GDP_constant_USD_mn ) ///
			robust orth nodiffsargan */
		
// Unsure what this model would return - J		
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[l3.ln_pub_gerd_constant_USD_mn]/(1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local ltcoeff = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
}





































// Models from 180911_Q5_3_1_OECD leverage panel (Dynamic panel) // NOT CLEAN TO USE - MISSING VARIOUS FILES

/*
sysdir set PLUS "L:\StataLib\ado\plus"

clear

set more off

cd "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data\Panel Data"

local path W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data\Panel Data

 
{ 
* Use R&D dataset
	use "`path'/180730_(Q5_3_1_GERD and HERD panel_for_reg_v13.dta", clear
	
	gen uk_ln_pub_herd_constant_USD_mn = ln_pub_herd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_herd_constant_USD_mn = 0 if uk_ln_pub_herd_constant_USD_mn == .
	
	gen oth_ln_pub_herd_constant_USD_mn = ln_pub_herd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_herd_constant_USD_mn = 0 if oth_ln_pub_herd_constant_USD_mn == .

* Correction for interest rates (missing values wrongly coded as zero)
	rename intrates intrates_old
	merge 1:1 year country using "OECD_interestrates_v13.dta"
	drop if _merge == 2
	drop _merge
	xtset country_code year

* Preparing GERD data
	preserve 
	use "`path'/180730_(Q5.5.1)_OECD_for_regressions_v13.dta", clear
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pub_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
	keep year country  pub_gerd_constant_USD_mn ln_pub_gerd_constant_USD_mn  uk_ln_pub_gerd_constant_USD_mn uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn
	save "path'/GERD to merge with (Q5.5.1)_OECD_for_regressions.dta", replace
	restore

* Preparing BERD data
	preserve 
	use "path'/180730_(Q5_3_2_BERD and GERD panel_for_reg.dta", clear
	gen uk_ln_pub_berd_constant_USD_mn = ln_pub_berd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_berd_constant_USD_mn = 0 if uk_ln_pub_berd_constant_USD_mn == .
	
	gen oth_ln_pub_berd_constant_USD_mn = ln_pub_berd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_berd_constant_USD_mn = 0 if oth_ln_pub_berd_constant_USD_mn == .
	
	keep year country  pub_berd_constant_USD_mn ln_pub_berd_constant_USD_mn  uk_ln_pub_berd_constant_USD_mn uk_ln_pub_berd_constant_USD_mn oth_ln_pub_berd_constant_USD_mn
	save "path'/BERD to merge with (Q5.3.1)_OECD_for_regressions.dta", replace
	restore

* Merging GERD
	merge 1:1 year country using "path'/GERD to merge with (Q5.5.1)_OECD_for_regressions.dta"
	drop if _merge != 3
	drop _merge

* Merging BERD
	merge 1:1 year country using "path'/BERD to merge with (Q5.3.1)_OECD_for_regressions.dta"
	drop if _merge != 3
	drop _merge
	
	drop if ln_pub_gerd_constant_USD_mn == 0 & ln_pub_herd_constant_USD_mn == 0
	
	xtset country_code year
	
	gen pub_oth_gerd_constant_USD_mn = pub_gerd_constant_USD_mn - pub_herd_constant_USD_mn - pub_berd_constant_USD_mn 
	gen ln_pub_oth_gerd_constant_USD_mn = ln(pub_oth_gerd_constant_USD_mn)
			
* Save
	save "path'/80730_(Q5_3_1and2_BERD and HERD panel_for_reg.dta", replace
********************************************************************************
* Dynamic panel - 1
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel

* Dynamic panel - 2
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(1 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel

* Dynamic panel - 3
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(1 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 4
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_GDP_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 5
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			ln_GDP_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GDP_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 6
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_GVA_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GVA_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 7
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_capitalstock_2005USDm intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_capitalstock_2005USDm , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
		
* Dynamic panel - 8
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_GFCF_constant_USD_mn intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_GFCF_constant_USD_mn , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 9
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_inventory_change_constantUSD intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_inventory_change_constantUSD , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 10
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates  ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands  , laglimit(1 6)  coll  ) ///
			iv(intrates HHI) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 11
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI ln_ex_rate_perusd ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands HHI , laglimit(1 6)  coll  ) ///
			iv(intrates ln_ex_rate_perusd) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 12
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates HHI exports_GDPshare ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands HHI , laglimit(1 6)  coll  ) ///
			iv(intrates exports_GDPshare) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 13
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_COE_constant_USD_mn intrates HHI exports_GDPshare ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_COE_constant_USD_mn HHI , laglimit(1 6)  coll  ) ///
			iv(intrates exports_GDPshare) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 14
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_QALI intrates HHI exports_GDPshare ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_QALI HHI , laglimit(1 6)  coll  ) ///
			iv(intrates exports_GDPshare) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 15
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_berd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_berd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel

* Dynamic panel - 15
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn   , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 3) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(2 3)  coll  ) ///  
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
		
* Dynamic panel - 1b
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn , ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn , laglimit(3 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
	export_dynamic_panel
	
* Dynamic panel - 2b
	xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn ///
			d.ln_employment_thousands intrates ///
			ln_pub_herd_constant_USD_mn  ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn, ///
			gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2) coll  ) ///
			gmm(ln_pub_herd_constant_USD_mn, laglimit(1 3)  coll  ) ///  
			gmm(ln_pub_berd_constant_USD_mn ln_pub_oth_gerd_constant_USD_mn, laglimit(2 3)  coll  ) ///
			gmm(d.ln_employment_thousands , laglimit(1 6)  coll  ) ///
			iv(intrates) ///
			robust orth nodiffsargan 
		export_dynamic_panel
	
	}
*/
	
	
// Models from 180917_Q5_5_1_OECD leverage panel (Dynamic panel) - UK // Figure 23

	
sysdir set PLUS "L:\StataLib\ado\plus"

clear

set more off

cd "W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data\Panel Data"

local path W:\STI-ANALYSIS-TEAM\Leverage Work Oxford Economics\Leverage Project Re-Run\Data\Panel Data	
	
	* Use R&D dataset
	use "`path'\180730_(Q5.5.1)_OECD_for_regressions_v13.dta", clear
	
	gen uk_ln_pub_gerd_constant_USD_mn = ln_pvt_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pub_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pub_gerd_constant_USD_mn = ln_pvt_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pub_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .
	
	gen uk_ln_pvt_gerd_constant_USD_mn = ln_pvt_gerd_constant_USD_mn if country == "United Kingdom"
	replace uk_ln_pvt_gerd_constant_USD_mn = 0 if uk_ln_pub_gerd_constant_USD_mn == .
	
	gen oth_ln_pvt_gerd_constant_USD_mn = ln_pvt_gerd_constant_USD_mn if country != "United Kingdom"
	replace oth_ln_pvt_gerd_constant_USD_mn = 0 if oth_ln_pub_gerd_constant_USD_mn == .

* Correction for interest rates (missing values wrongly coded as zero)
	rename intrates intrates_old
	replace country = "Korea" if country == "South Korea"
	merge 1:1 year country using "`path'\OECD_interestrates_v13.dta"
	drop if _merge == 2
	replace country = "South Korea" if country == "Korea"
	xtset country_code year
	
********************************************************************************
//    Model 1 - corresponds with Figure 23 Column 2    //   Dynamic panel - 1		 						
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn , laglimit(1 2)  coll orth ) gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) iv(intrates) robust orth nodiffsargan 	
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
		nlcom (_b[uk_ln_pub_gerd_constant_USD_mn] - _b[oth_ln_pub_gerd_constant_USD_mn])
			nlcom (_b[uk_ln_pub_gerd_constant_USD_mn]/ (1-_b[l.ln_pvt_gerd_constant_USD_mn]))
	
		
		matrix b = r(b)
		matrix V = r(V)
		local diff_UKvsRoW = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
	
			
//    Model 2 - corresponds with Figure 23 Column 3    //  Dynamic panel - 8								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates, gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 5)  coll orth ) iv(intrates) robust orth nodiffsargan 
			
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
	nlcom (_b[uk_ln_pub_gerd_constant_USD_mn] - _b[oth_ln_pub_gerd_constant_USD_mn])
		nlcom (_b[uk_ln_pub_gerd_constant_USD_mn]/ (1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local diff_UKvsRoW = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		
	
//    Model 3 - corresponds with Figure 23 Column 4    //  Dynamic panel - 14								
		xtabond2 ln_pvt_gerd_constant_USD_mn l.ln_pvt_gerd_constant_USD_mn  uk_ln_pub_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn d.ln_employment_thousands intrates ln_ex_rate_perusd, gmm(l.ln_pvt_gerd_constant_USD_mn  , laglimit(2 2)  coll orth ) gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 5)  coll orth ) gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 2)  coll orth ) iv(intrates ln_ex_rate_perusd) robust orth nodiffsargan 
		
		local instru = e(j)
		local AR2stat = e(ar2p)
		local sarganp = e(sarganp)
		local hansenp = e(hansenp)
		
	*Long run	
	nlcom (_b[uk_ln_pub_gerd_constant_USD_mn] - _b[oth_ln_pub_gerd_constant_USD_mn])
		nlcom (_b[uk_ln_pub_gerd_constant_USD_mn]/ (1-_b[l.ln_pvt_gerd_constant_USD_mn]))
		
		matrix b = r(b)
		matrix V = r(V)
		local diff_UKvsRoW = b[1,1]
		local std_err = sqrt(V[1,1])
		local z = b[1,1]/`std_err'
		local pvalue = 2*normal(-abs(`z'))
		


// Josh attempt at Trialling the model to split private Gerd by UK and other OECD countries //		
xtabond2 ln_pvt_gerd_constant_USD_mn l.uk_ln_pvt_gerd_constant_USD_mn uk_ln_pub_gerd_constant_USD_mn  d.ln_employment_thousands intrates, gmm(l.uk_ln_pvt_gerd_constant_USD_mn , laglimit(1 2)  coll orth )  gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) iv(intrates) robust orth nodiffsargan 	
	
xtabond2 oth_ln_pvt_gerd_constant_USD_mn l.oth_ln_pvt_gerd_constant_USD_mn oth_ln_pub_gerd_constant_USD_mn  d.ln_employment_thousands intrates, gmm(l.oth_ln_pvt_gerd_constant_USD_mn , laglimit(1 2)  coll orth )  gmm(oth_ln_pub_gerd_constant_USD_mn  , laglimit(1 2)  coll orth ) gmm(uk_ln_pub_gerd_constant_USD_mn , laglimit(1 5)  coll orth ) gmm(d.ln_employment_thousands , laglimit(1 1)  coll orth ) iv(intrates) robust orth nodiffsargan 	
